@@ -1054,11 +1054,7 @@ int Write_VAR_Parameters_Mat(TStateModel *model, char *out_tag)
 #if defined(MATLAB_MEX_FILE)
   MATFile *matFile;
 #else
-# if MATIO_MAJOR_VERSION > 1 || (MATIO_MAJOR_VERSION == 1 && MATIO_MINOR_VERSION >= 5)
   size_t dims_i[3];
-#else
-  int dims_i[3];
-#endif
   mat_t *matFile;
   matvar_t *towrite;
 #endif
@@ -1102,11 +1098,7 @@ int Write_VAR_Parameters_Mat(TStateModel *model, char *out_tag)
   for (i=0; i<3; i++)
     dims_i[i] = dims[i];
   towrite = Mat_VarCreate("A0", MAT_C_DOUBLE, MAT_T_DOUBLE, 3, dims_i, data, 0);
-# if MATIO_MAJOR_VERSION > 1 || (MATIO_MAJOR_VERSION == 1 && MATIO_MINOR_VERSION >= 5)
   status = Mat_VarWrite(matFile, towrite, MAT_COMPRESSION_NONE);
-#else
-  status = Mat_VarWrite(matFile, towrite, COMPRESSION_NONE);
-#endif
 #endif
   if (status != 0)
     {
@@ -1131,11 +1123,7 @@ int Write_VAR_Parameters_Mat(TStateModel *model, char *out_tag)
   for (i=0; i<2; i++)
     dims_i[i] = dims[i];
   towrite = Mat_VarCreate("Aplus", MAT_C_DOUBLE, MAT_T_DOUBLE, 3, dims_i, data, 0);
-# if MATIO_MAJOR_VERSION > 1 || (MATIO_MAJOR_VERSION == 1 && MATIO_MINOR_VERSION >= 5)
   status = Mat_VarWrite(matFile, towrite, MAT_COMPRESSION_NONE);
-#else
-  status = Mat_VarWrite(matFile, towrite, COMPRESSION_NONE);
-#endif
 #endif
   if (status != 0)
     {
@@ -1160,11 +1148,7 @@ int Write_VAR_Parameters_Mat(TStateModel *model, char *out_tag)
   for (i=0; i<2; i++)
     dims_i[i] = dims[i];
   towrite = Mat_VarCreate("Zeta", MAT_C_DOUBLE, MAT_T_DOUBLE, 3, dims_i, data, 0);
-# if MATIO_MAJOR_VERSION > 1 || (MATIO_MAJOR_VERSION == 1 && MATIO_MINOR_VERSION >= 5)
   status = Mat_VarWrite(matFile, towrite, MAT_COMPRESSION_NONE);
-#else
-  status = Mat_VarWrite(matFile, towrite, COMPRESSION_NONE);
-#endif
 #endif
   if (status != 0)
     {
@@ -1189,11 +1173,7 @@ int Write_VAR_Parameters_Mat(TStateModel *model, char *out_tag)
   for (i=0; i<3; i++)
     dims_i[i] = dims[i];
   towrite = Mat_VarCreate("Q", MAT_C_DOUBLE, MAT_T_DOUBLE, 2, dims_i, data, 0);
-# if MATIO_MAJOR_VERSION > 1 || (MATIO_MAJOR_VERSION == 1 && MATIO_MINOR_VERSION >= 5)
   status = Mat_VarWrite(matFile, towrite, MAT_COMPRESSION_NONE);
-#else
-  status = Mat_VarWrite(matFile, towrite, COMPRESSION_NONE);
-#endif
 #endif
   if (status != 0)
     {
