@@ -69,12 +69,21 @@ function [a, a1, P, P1, v, Fi, Ki, T, R, C, regimes_, error_flag, M_, alphahat,
 % You should have received a copy of the GNU General Public License
 % along with Dynare.  If not, see <https://www.gnu.org/licenses/>.
 
+warning off
+
+options_.noprint = true;
+T=[];
+R=[];
+C=[];
+regimes_ = struct();
+
 if isempty(nk)
     nk=1;
 end
 nk=max(nk,1);
 
-opts_simul = occbin_options.opts_regime;base_regime = struct();
+opts_simul = occbin_options.opts_regime;
+base_regime = struct();
 if M_.occbin.constraint_nbr==1
     base_regime.regime = 0;
     base_regime.regimestart = 1;
@@ -121,6 +130,10 @@ end
 
 options_.occbin.simul=opts_simul;
 [~, out, ss] = occbin.solver(M_,oo_,options_);
+if out.error_flag
+    error_flag = out.error_flag;
+    return;
+end
 
 regimes_ = out.regime_history;
 if M_.occbin.constraint_nbr==1
@@ -210,6 +223,10 @@ if any(myregime) || ~isequal(regimes_(1),regimes0(1))
         opts_simul.periods = max(opts_simul.periods,max(myregimestart));
         options_.occbin.simul=opts_simul;
         [~, out, ss] = occbin.solver(M_,oo_,options_);
+        if out.error_flag
+            error_flag = out.error_flag;
+            return;
+        end
         regimes0=regimes_;
         regimes_ = out.regime_history;
         if niter>1
@@ -290,7 +307,7 @@ if error_flag==0 && niter>options_.occbin.likelihood.max_number_of_iterations &&
         CC(:,2) = CCx(:,end);
         [a, a1, P, P1, v, Fi, Ki, alphahat, etahat] = occbin_kalman_update(a,a1,P,P1,data_index,Z,v,Y,H,QQQ,TT,RR,CC,Ki,Fi,mm,kalman_tol);
         opts_simul.SHOCKS(1,:) = etahat(:,2)';
-        if occbin_options.opts_algo.restrict_state_space
+        if opts_simul.restrict_state_space
             tmp=zeros(M_.endo_nbr,1);
             tmp(oo_.dr.restrict_var_list,1)=alphahat(:,1);
             opts_simul.endo_init = tmp(oo_.dr.inv_order_var,1);
