@@ -189,6 +189,7 @@ elseif options_.lik_init == 2           % Old Diffuse Kalman filter
     Pstar = options_.Harvey_scale_factor*eye(np);
     Pinf        = [];
 elseif options_.lik_init == 3           % Diffuse Kalman filter
+    my_mf = mf;
     if kalman_algo ~= 4
         kalman_algo = 3;
     else
@@ -201,9 +202,10 @@ elseif options_.lik_init == 3           % Diffuse Kalman filter
             R  = blkdiag(R,eye(vobs));
             H   = zeros(vobs,vobs);
             Z   = [Z, eye(vobs)];
+            my_mf = find(any(Z))';
         end
     end
-    [Pstar,Pinf] = compute_Pinf_Pstar(mf,T,R,Q,options_.qz_criterium);
+    [Pstar,Pinf] = compute_Pinf_Pstar(my_mf,T,R,Q,options_.qz_criterium);
 elseif options_.lik_init == 4           % Start from the solution of the Riccati equation.
     Pstar = kalman_steady_state(transpose(T),R*Q*transpose(R),transpose(build_selection_matrix(mf,np,vobs)),H);
     Pinf  = [];
@@ -363,6 +365,12 @@ else
         ic = oo_.dr.restrict_columns;
     end
     
+    if isempty(options_.nk)
+        nk=1;
+    else
+        nk=options_.nk;
+    end
+        
     if options_.occbin.smoother.status
         % reconstruct occbin smoother
         if length_varargin>0
@@ -452,7 +460,7 @@ else
                 opts_simul.check_ahead_periods = options_.occbin.smoother.check_ahead_periods;
                 opts_simul.full_output = options_.occbin.smoother.full_output;
                 opts_simul.piecewise_only = options_.occbin.smoother.piecewise_only;
-                opts_simul.SHOCKS = zeros(options_.nk,M_.exo_nbr);
+                opts_simul.SHOCKS = zeros(nk,M_.exo_nbr);
                 opts_simul.SHOCKS(1,:) =  eehat(:,k);
                 tmp=zeros(M_.endo_nbr,1);
                 tmp(oo_.dr.restrict_var_list,1)=aahat(:,k-1);
@@ -485,7 +493,7 @@ else
             clear sstate_uncertainty
         end
         
-        aaa = zeros(options_.nk,M_.endo_nbr,gend+options_.nk);
+        aaa = zeros(nk,M_.endo_nbr,gend+nk);
         aaa(:,oo_.dr.restrict_var_list,:)=aK;
         
         for k=2:gend+1
@@ -496,7 +504,7 @@ else
             opts_simul.check_ahead_periods = options_.occbin.smoother.check_ahead_periods;
             opts_simul.full_output = options_.occbin.smoother.full_output;
             opts_simul.piecewise_only = options_.occbin.smoother.piecewise_only;
-            opts_simul.SHOCKS = zeros(options_.nk,M_.exo_nbr);
+            opts_simul.SHOCKS = zeros(nk,M_.exo_nbr);
             tmp=zeros(M_.endo_nbr,1);
             tmp(oo_.dr.restrict_var_list,1)=ahat0(:,k-1);
             opts_simul.endo_init = tmp(oo_.dr.inv_order_var,1);
@@ -508,14 +516,14 @@ else
             % period ahead (so if regimestart was [1 5] it should be [1 4]
             % in out
             %         end
-            for jnk=1:options_.nk
+            for jnk=1:nk
                 aaa(jnk,oo_.dr.inv_order_var,k+jnk-1) = out.piecewise(jnk,:) - out.ys';
             end
         end
         aK=aaa;
         
         if ~isempty(PK)
-            PP = zeros(options_.nk,M_.endo_nbr,M_.endo_nbr,gend+options_.nk);
+            PP = zeros(nk,M_.endo_nbr,M_.endo_nbr,gend+nk);
             PP(:,oo_.dr.restrict_var_list,oo_.dr.restrict_var_list,:) = PK;
             PK=PP;
             clear PP
@@ -561,20 +569,17 @@ else
         end
         ahat1=aaa;
         % reconstruct aK
-        if isempty(options_.nk)
-            options_.nk=1;
-        end
-        aaa = zeros(options_.nk,M_.endo_nbr,gend+options_.nk);
+        aaa = zeros(nk,M_.endo_nbr,gend+nk);
         aaa(:,oo_.dr.restrict_var_list,:)=aK;
         for k=1:gend
-            for jnk=1:options_.nk
+            for jnk=1:nk
                 aaa(jnk,static_var_list,k+jnk) = C(~ilagged,:)*dynare_squeeze(aK(jnk,:,k+jnk));
             end
         end
         if any(ilagged)
             for k=1:gend
                 aaa(1,static_var_list0,k+1) = Tstar(ilagged,:)*ahat(:,k);
-                for jnk=2:options_.nk
+                for jnk=2:nk
                     aaa(jnk,static_var_list0,k+jnk) = Tstar(ilagged,:)*dynare_squeeze(aK(jnk-1,:,k+jnk-1));
                 end
             end
@@ -621,12 +626,12 @@ else
         
         % reconstruct PK
         if ~isempty(PK)
-            PP = zeros(options_.nk,M_.endo_nbr,M_.endo_nbr,gend+options_.nk);
+            PP = zeros(nk,M_.endo_nbr,M_.endo_nbr,gend+nk);
             PP(:,oo_.dr.restrict_var_list,oo_.dr.restrict_var_list,:) = PK;
             if ~options_.heteroskedastic_filter
                 DQD=D(~ilagged,:)*Q*transpose(D(~ilagged,:))+C(~ilagged,:)*R*Q*transpose(D(~ilagged,:))+D(~ilagged,:)*Q*transpose(C(~ilagged,:)*R);
                 DQR=D(~ilagged,:)*Q*transpose(R);
-                for f=1:options_.nk
+                for f=1:nk
                     for k=1:gend
                         PP(f,static_var_list,static_var_list,k+f)=C(~ilagged,:)*squeeze(PK(f,:,:,k+f))*C(~ilagged,:)'+DQD;
                         PP(f,static_var_list,oo_.dr.restrict_var_list,k+f)=C(~ilagged,:)*squeeze(PK(f,:,:,k+f))+DQR;
