@@ -45,7 +45,7 @@ function myoutput=PosteriorIRF_core2(myinputs,fpar,npar,whoiam,ThisMatlab)
 % GNU General Public License for more details.
 %
 % You should have received a copy of the GNU General Public License
-% along with Dynare.  If not, see <http://www.gnu.org/licenses/>.
+% along with Dynare.  If not, see <https://www.gnu.org/licenses/>.
 
 global options_  M_
 
@@ -142,8 +142,11 @@ for i=fpar:npar
                 remove_fractional_xticks;
                 hold off
             end
-            name = varlist{j};
-            title(name,'Interpreter','none')
+            if options_.TeX
+                title(['$' varlist_TeX{j} '$'],'Interpreter','latex')               
+            else
+                title(varlist{j},'Interpreter','none')
+            end
         else
             if options_.debug
                 fprintf('POSTERIOR_IRF: The IRF of %s to %s is smaller than the irf_plot_threshold of %4.3f and will not be displayed.\n',varlist{j},tit{i},options_.impulse_responses.plot_threshold)
