@@ -2,7 +2,7 @@ function oo_ = disp_th_moments(dr, var_list, M_, options_, oo_)
 
 % Display theoretical moments of variables
 
-% Copyright (C) 2001-2018 Dynare Team
+% Copyright (C) 2001-2021 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -17,11 +17,11 @@ function oo_ = disp_th_moments(dr, var_list, M_, options_, oo_)
 % GNU General Public License for more details.
 %
 % You should have received a copy of the GNU General Public License
-% along with Dynare.  If not, see <http://www.gnu.org/licenses/>.
+% along with Dynare.  If not, see <https://www.gnu.org/licenses/>.
 
 nodecomposition = options_.nodecomposition;
 if options_.one_sided_hp_filter
-    error(['disp_th_moments:: theoretical moments incompatible with one-sided HP filter. Use simulated moments instead'])
+    error('disp_th_moments:: theoretical moments incompatible with one-sided HP filter. Use simulated moments instead')
 end
 if isempty(var_list)
     var_list = M_.endo_names(1:M_.orig_endo_nbr);
@@ -55,7 +55,7 @@ oo_.var = oo_.gamma_y{1};
 
 ME_present=0;
 if ~all(diag(M_.H)==0)
-    if isoctave || matlab_ver_less_than('8.1')
+    if isoctave && octave_ver_less_than('6')
         [observable_pos_requested_vars,index_subset,index_observables]=intersect_stable(ivar,options_.varobs_id);
     else
         [observable_pos_requested_vars,index_subset,index_observables]=intersect(ivar,options_.varobs_id,'stable');
@@ -82,11 +82,11 @@ if size(stationary_vars, 1) > 0
         end
         title = add_filter_subtitle(title, options_);
         headers = {'VARIABLE';'MEAN';'STD. DEV.';'VARIANCE'};
-        labels = M_.endo_names(ivar);
+        labels=get_labels_transformed_vars(M_.endo_names,ivar,options_,false);
         lh = cellofchararraymaxlength(labels)+2;
         dyntable(options_, title, headers, labels, z, lh, 11, 4);
         if options_.TeX
-            labels = M_.endo_names_tex(ivar);
+            labels=get_labels_transformed_vars(M_.endo_names_tex,ivar,options_,true);
             lh = cellofchararraymaxlength(labels)+2;
             dyn_latex_table(M_, options_, title, 'th_moments', headers, labels, z, lh, 11, 4);
         end
@@ -102,26 +102,29 @@ if size(stationary_vars, 1) > 0
             headers = M_.exo_names;
             headers(M_.exo_names_orig_ord) = headers;
             headers = vertcat(' ', headers);
-            lh = cellofchararraymaxlength(M_.endo_names(ivar(stationary_vars)))+2;
-            dyntable(options_, title, headers, M_.endo_names(ivar(stationary_vars)), 100*oo_.gamma_y{options_.ar+2}(stationary_vars,:), lh, 8, 2);
+            labels=get_labels_transformed_vars(M_.endo_names,ivar(stationary_vars),options_,false);
+            lh = cellofchararraymaxlength(labels)+2;
+            dyntable(options_, title, headers, labels, 100*oo_.gamma_y{options_.ar+2}(stationary_vars,:), lh, 8, 2);
             if ME_present
-                if isoctave || matlab_ver_less_than('8.1')
+                if isoctave && octave_ver_less_than('6')
                     [stationary_observables, pos_index_subset] = intersect_stable(index_subset, stationary_vars);
                 else
                     [stationary_observables, pos_index_subset] = intersect(index_subset, stationary_vars, 'stable');
                 end
                 headers_ME = vertcat(headers, 'ME');
-                dyntable(options_, [title,' WITH MEASUREMENT ERROR'], headers_ME, M_.endo_names(ivar(stationary_observables)), ...
+                labels=get_labels_transformed_vars(M_.endo_names,ivar(stationary_observables),options_,false);
+                dyntable(options_, [title,' WITH MEASUREMENT ERROR'], headers_ME, labels, ...
                          oo_.variance_decomposition_ME(pos_index_subset,:), lh, 8, 2);
             end
             if options_.TeX
                 headers = M_.exo_names_tex;
                 headers = vertcat(' ', headers);
-                labels = M_.endo_names_tex(ivar(stationary_vars));
+                labels=get_labels_transformed_vars(M_.endo_names_tex,ivar(stationary_vars),options_,true);
                 lh = cellofchararraymaxlength(labels)+2;
                 dyn_latex_table(M_, options_, title, 'th_var_decomp_uncond', headers, labels, 100*oo_.gamma_y{options_.ar+2}(stationary_vars,:), lh, 8, 2);
                 if ME_present
                     headers_ME = vertcat(headers, 'ME');
+                    labels=get_labels_transformed_vars(M_.endo_names_tex,ivar(stationary_observables),options_,true);
                     dyn_latex_table(M_, options_, [title,' WITH MEASUREMENT ERROR'], ...
                                     'th_var_decomp_uncond_ME', headers_ME, labels, oo_.variance_decomposition_ME(pos_index_subset,:), lh, 8, 2);
                 end
@@ -129,7 +132,7 @@ if size(stationary_vars, 1) > 0
         end
     end
     conditional_variance_steps = options_.conditional_variance_decomposition;
-    if length(conditional_variance_steps)
+    if ~isempty(conditional_variance_steps)
         StateSpaceModel.number_of_state_equations = M_.endo_nbr;
         StateSpaceModel.number_of_state_innovations = M_.exo_nbr;
         StateSpaceModel.sigma_e_is_diagonal = M_.sigma_e_is_diagonal;
@@ -151,10 +154,12 @@ if size(stationary_vars, 1) > 0
     end
 end
 
-if length(i1) == 0
-    skipline()
-    disp('All endogenous are constant or non stationary, not displaying correlations and auto-correlations')
-    skipline()
+if isempty(i1)
+    if ~options_.noprint
+        skipline()
+        disp('All endogenous are constant or non stationary, not displaying correlations and auto-correlations')
+        skipline()
+    end
     return
 end
 
@@ -172,12 +177,12 @@ if ~options_.nocorr && size(stationary_vars, 1)>0
             title = 'MATRIX OF CORRELATIONS';
         end
         title = add_filter_subtitle(title, options_);
-        labels = M_.endo_names(ivar(i1));
+        labels=get_labels_transformed_vars(M_.endo_names,ivar(i1),options_,false);
         headers = vertcat('Variables', labels);
         lh = cellofchararraymaxlength(labels)+2;
         dyntable(options_, title, headers, labels, corr(i1,i1), lh, 8, 4);
         if options_.TeX
-            labels = M_.endo_names_tex(ivar(i1));
+            labels=get_labels_transformed_vars(M_.endo_names_tex,ivar(i1),options_,true);
             headers = vertcat('Variables', labels);
             lh = cellofchararraymaxlength(labels)+2;
             dyn_latex_table(M_, options_, title, 'th_corr_matrix', headers, labels, corr(i1,i1), lh, 8, 4);
@@ -186,7 +191,7 @@ if ~options_.nocorr && size(stationary_vars, 1)>0
 end
 
 if options_.ar > 0 && size(stationary_vars, 1) > 0
-    z=[];
+    z=NaN(length(i1),options_.ar);
     for i=1:options_.ar
         oo_.autocorr{i} = oo_.gamma_y{i+1};
         z(:,i) = diag(oo_.gamma_y{i+1}(i1,i1));
@@ -199,12 +204,12 @@ if options_.ar > 0 && size(stationary_vars, 1) > 0
             title = 'COEFFICIENTS OF AUTOCORRELATION';
         end
         title = add_filter_subtitle(title, options_);
-        labels = M_.endo_names(ivar(i1));
+            labels=get_labels_transformed_vars(M_.endo_names,ivar(i1),options_,false);
         headers = vertcat('Order ', cellstr(int2str([1:options_.ar]')));
         lh = cellofchararraymaxlength(labels)+2;
         dyntable(options_, title, headers, labels, z, lh, 8, 4);
         if options_.TeX
-            labels = M_.endo_names_tex(ivar(i1));
+            labels=get_labels_transformed_vars(M_.endo_names_tex,ivar(i1),options_,true);
             headers = vertcat('Order ', cellstr(int2str([1:options_.ar]')));
             lh = cellofchararraymaxlength(labels)+2;
             dyn_latex_table(M_, options_, title, 'th_autocorr_matrix', headers, labels, z, lh, 8, 4);
