@@ -4,7 +4,7 @@ function dyn_waitbar_close(h)
 % octave and when console_mode=1
 
 %
-% Copyright (C) 2011-2017 Dynare Team
+% Copyright (C) 2011-2021 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -19,10 +19,10 @@ function dyn_waitbar_close(h)
 % GNU General Public License for more details.
 %
 % You should have received a copy of the GNU General Public License
-% along with Dynare.  If not, see <http://www.gnu.org/licenses/>.
+% along with Dynare.  If not, see <https://www.gnu.org/licenses/>.
 global options_
 
-if isoctave || options_.console_mode
+if options_.console_mode
     clear dyn_waitbar;
     diary on
     fprintf('\n');
