@@ -16,7 +16,7 @@ function dynare(fname, varargin)
 % SPECIAL REQUIREMENTS
 %   none
 
-% Copyright (C) 2001-2020 Dynare Team
+% Copyright (C) 2001-2021 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -31,7 +31,7 @@ function dynare(fname, varargin)
 % GNU General Public License for more details.
 %
 % You should have received a copy of the GNU General Public License
-% along with Dynare.  If not, see <http://www.gnu.org/licenses/>.
+% along with Dynare.  If not, see <https://www.gnu.org/licenses/>.
 
 if ~nargin || strcmpi(fname,'help')
     skipline()
@@ -76,16 +76,16 @@ if isoctave
                  'of precompiled mex files and some\nfeatures, like solution ' ...
                  'of models approximated at third order, will not be available.'], supported_octave_version())
         skipline()
-    elseif octave_ver_less_than('4.2') % Should match the test in mex/build/octave/configure.ac
-                                       % and in m4/ax_mexopts.m4
+    elseif octave_ver_less_than('5.1.0') % Should match the test in mex/build/octave/configure.ac, and also the one in matlab/modules/dseries/src/initialize_dseries_class.m
         skipline()
-        warning(['This version of Dynare has only been tested on Octave 4.2 and above. Dynare may fail to run or give unexpected result. Consider upgrading your version of Octave.'])
+        warning(['This version of Dynare has only been tested on Octave 5.1.0 and above. Dynare may fail to run or give unexpected result. Consider upgrading your version of Octave.'])
         skipline()
     end
 else
-    if matlab_ver_less_than('7.9') % Should match the test in mex/build/matlab/configure.ac
+    if matlab_ver_less_than('8.3') % Should match the test in mex/build/matlab/configure.ac
+                                   % and in m4/ax_mexopts.m4
         skipline()
-        warning('This version of Dynare has only been tested on MATLAB 7.9 (R2009b) and above. Since your MATLAB version is older than that, Dynare may fail to run, or give unexpected results. Consider upgrading your MATLAB installation, or switch to Octave.');
+        warning('This version of Dynare has only been tested on MATLAB 8.3 (R2014a) and above. Since your MATLAB version is older than that, Dynare may fail to run, or give unexpected results. Consider upgrading your MATLAB installation, or switch to Octave.');
         skipline()
     end
 end
@@ -137,14 +137,6 @@ if fnamelength + length('.set_auxiliary_variables') > namelengthmax()
     error('Dynare: the name of your .mod file is too long, please shorten it')
 end
 
-% Workaround for a strange bug with Octave: if there is any call to exist(fname)
-% before the call to the preprocessor, then Octave will use the old copy of
-% the .m instead of the newly generated one. Deleting the .m beforehand
-% fixes the problem.
-if isoctave && length(dir([fname(1:(end-4)) '.m'])) > 0
-    delete([fname(1:(end-4)) '.m'])
-end
-
 if ~isempty(strfind(fname,filesep))
     fprintf('\nIt seems you are trying to call a .mod file not located in the "Current Folder". This is not possible (the %s symbol is not allowed in the name of the .mod file).\n', filesep)
     [pathtomodfile,basename] = fileparts(fname);
@@ -192,22 +184,14 @@ nolog = ismember('nolog', varargin) || ismember('nolog', file_opts);
 onlymacro = ismember('onlymacro', varargin) || ismember('onlymacro', file_opts);
 onlyjson = ismember('onlyjson', varargin) || ismember('onlyjson', file_opts);
 
-if ispc
-    arch = getenv('PROCESSOR_ARCHITECTURE');
-else
-    [~, arch] = system('uname -m');
-end
-
-if isempty(strfind(arch, '64'))
-    arch_ext = '32';
-    if preprocessoroutput
-        disp('Using 32-bit preprocessor');
-    end
-else
-    arch_ext = '64';
-    if preprocessoroutput
-        disp('Using 64-bit preprocessor');
+% Start journal
+diary off
+if ~nolog
+    logfile = [ fname(1:end-4) '.log' ];
+    if exist(logfile, 'file')
+        delete(logfile)
     end
+    diary(logfile)
 end
 
 if preprocessoroutput
@@ -220,7 +204,7 @@ if preprocessoroutput
     end
 end
 
-command = ['"' dynareroot 'preprocessor' arch_ext filesep 'dynare_m" ' fname] ;
+command = ['"' dynareroot '..' filesep 'preprocessor' filesep 'dynare-preprocessor" ' fname] ;
 command = [ command ' mexext=' mexext ' "matlabroot=' matlabroot '"'];
 % Properly quote arguments before passing them to the shell
 if ~isempty(varargin)
@@ -238,6 +222,16 @@ if ~isempty(varargin)
     command = [command ' ' dynare_varargin];
 end
 
+% On MATLAB+Windows, the +folder may be locked by MATLAB, preventing its
+% removal by the preprocessor.
+% Trying to delete it here will actually fail, but surprisingly this allows
+% the preprocessor to actually remove the folder (see ModFile::writeOutputFiles())
+% For an instance of this bug, see:
+% https://forum.dynare.org/t/issue-with-dynare-preprocessor-4-6-1/15448/1
+if ispc && ~isoctave && exist(['+',fname(1:end-4)],'dir')
+    [~,~]=rmdir(['+', fname(1:end-4)],'s');
+end
+
 % Under Windows, make sure the MEX file is unloaded (in the use_dll case),
 % otherwise the preprocessor can't recompile it
 if isoctave
@@ -269,15 +263,8 @@ if exist(fname(1:end-4),'dir') && exist([fname(1:end-4) filesep 'hooks'],'dir')
     run([fname(1:end-4) filesep 'hooks/postprocessing'])
 end
 
-% Save preprocessor result in logfile (if `no_log' option not present)
-if ~nolog
-    logname = [fname(1:end-4) '.log'];
-    fid = fopen(logname, 'w');
-    fprintf(fid, '%s', result);
-    fclose(fid);
-end
-
 if status
+    diary off
     % Should not use "error(result)" since message will be truncated if too long
     error('Dynare: preprocessing failed')
 end
@@ -290,7 +277,19 @@ end
 % within the driver will clean the rest)
 clear(['+' fname '/driver'])
 
-evalin('base',[fname '.driver']) ;
+try
+    evalin('base',[fname '.driver']);
+catch ME
+    W = evalin('caller','whos');
+    diary off
+    if ismember(fname,{W(:).name})
+        error('Your workspace already contains a variable with the same name as the mod-file. You need to delete it or rename the mod-file.')
+    else
+        rethrow(ME)
+    end
+end
+
+diary off
 
 end
 
