@@ -12,7 +12,7 @@ function oo_recursive_=dynare_estimation(var_list,dname)
 % SPECIAL REQUIREMENTS
 %   none
 
-% Copyright (C) 2003-2020 Dynare Team
+% Copyright (C) 2003-2021 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -27,7 +27,7 @@ function oo_recursive_=dynare_estimation(var_list,dname)
 % GNU General Public License for more details.
 %
 % You should have received a copy of the GNU General Public License
-% along with Dynare.  If not, see <http://www.gnu.org/licenses/>.
+% along with Dynare.  If not, see <https://www.gnu.org/licenses/>.
 
 global options_ oo_ M_ dataset_ dataset_info
 
@@ -43,6 +43,19 @@ if ~isempty(strmatch('dsge_prior_weight',M_.param_names))
     options_.dsge_var = 1;
 end
 
+% The TeX option crashes MATLAB R2014a run with "-nodisplay" option
+% (as is done from the testsuite).
+% Since we can’t directly test whether "-nodisplay" has been passed,
+% we test for the "TOP_TEST_DIR" environment variable, which is set
+% by the testsuite.
+% Note that it was not tested whether the crash happens with more
+% recent MATLAB versions, so when OLD_MATLAB_VERSION is increased,
+% one should make a test before removing this workaround.
+if options_.TeX && ~isoctave && matlab_ver_less_than('8.4') && ~isempty(getenv('TOP_TEST_DIR'))
+    warning('Disabling TeX option due to a bug in MATLAB R2014a with -nodisplay')
+    options_.TeX = false;
+end
+
 var_list = check_list_of_variables(options_, M_, var_list);
 options_.varlist = var_list;
 
@@ -88,7 +101,7 @@ if nnobs>1 || nfirstobs > 1
         end
         dynare_estimation_1(var_list,M_.dname);
         if isequal(i,1) && options_.mode_compute ~= 0
-            options_.mode_file = [M_.fname '_mode'];
+            options_.mode_file = [M_.dname filesep 'Output' filesep M_.fname '_mode'];
         end
         if options_.recursive_estimation_restart
             for j=1:options_.recursive_estimation_restart
@@ -144,10 +157,10 @@ if nnobs > 1 && horizon > 0
     k = time_offset+min(nobs(end)-nobs(1)+horizon, ...
                         size(dataset_.data,1)-nobs(1));
     data2 = dataset_info.rawdata(end-k+1:end,:);
-    [nbplt,nr,nc,lr,lc,nstar] = pltorg(nvar);
+    [~,nr,nc,~,~,nstar] = pltorg(nvar);
     m = 1;
     plot_index=0;
-    OutputDirectoryName = CheckPath('graphs',M_.fname);
+    OutputDirectoryName = CheckPath('graphs',M_.dname);
     for i = 1:length(var_list)
         if mod(i,nstar) == 1
             plot_index=plot_index+1;
@@ -208,7 +221,7 @@ if nnobs > 1 && horizon > 0
         xlim([nobs(1)-offsetx nobs(end)+horizon])
         m = m + 1;
         if mod(i+1,nstar) == 1 || i==length(var_list)
-            dyn_saveas(hfig,[M_.fname,filesep,'graphs',filesep M_.fname '_RecursiveForecasts_' int2str(plot_index)],options_.nodisplay,options_.graph_format);
+            dyn_saveas(hfig,[M_.dname,filesep,'graphs',filesep M_.fname '_RecursiveForecasts_' int2str(plot_index)],options_.nodisplay,options_.graph_format);
         end
     end
 end
@@ -216,3 +229,9 @@ options_.mode_file = mode_file0;
 %reset stored mode-file to user defined one (and in case it was only set by the recursive estimation)
 oo_.gui.ran_estimation = true;
 
+if isoctave && isfield(options_, 'prior_restrictions') && ...
+   isfield(options_.prior_restrictions, 'routine')
+    % Octave crashes if it tries to save function handles (to the _results.mat file)
+    % See https://savannah.gnu.org/bugs/?43215
+    options_.prior_restrictions.routine = [];
+end
