@@ -649,7 +649,7 @@ if options_.load_results_after_load_mh
 end
 
 if options_.mh_replic || options_.load_mh_file
-    [current_options, options_] = check_posterior_sampler_options([], options_, bounds);
+    [current_options, options_, bayestopt_] = check_posterior_sampler_options([], options_, bounds, bayestopt_);
     options_.posterior_sampler_options.current_options = current_options;
 end
 
@@ -699,4 +699,19 @@ if options_.occbin.likelihood.status && options_.occbin.likelihood.inversion_fil
             error('IVF-filter: an observable is mapped to a zero variance shock.')
         end
     end
+end
+
+if options_.occbin.smoother.status && options_.occbin.smoother.inversion_filter
+    if ~isempty(options_.nk)
+        fprintf('dynare_estimation_init: the inversion filter does not support filter_step_ahead. Disabling the option.\n')        
+        options_.nk=[];
+    end
+    if options_.filter_covariance
+        fprintf('dynare_estimation_init: the inversion filter does not support filter_covariance. Disabling the option.\n')        
+        options_.filter_covariance=false;
+    end
+    if options_.smoothed_state_uncertainty
+        fprintf('dynare_estimation_init: the inversion filter does not support smoothed_state_uncertainty. Disabling the option.\n')        
+        options_.smoothed_state_uncertainty=false;
+    end
 end
\ No newline at end of file
