@@ -1,6 +1,6 @@
 function e = euler_equation_error(y0,x,innovations,M,options,oo,pfm,nodes,weights)
 
-% Copyright (C) 2016-2017 Dynare Team
+% Copyright (C) 2016-2020 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -15,7 +15,7 @@ function e = euler_equation_error(y0,x,innovations,M,options,oo,pfm,nodes,weight
 % GNU General Public License for more details.
 %
 % You should have received a copy of the GNU General Public License
-% along with Dynare.  If not, see <http://www.gnu.org/licenses/>.
+% along with Dynare.  If not, see <https://www.gnu.org/licenses/>.
 
 dynamic_model = str2func([M.fname '.dynamic']);
 ep = options.ep;
@@ -23,7 +23,7 @@ ep = options.ep;
                                                   M.endo_nbr, M.exo_nbr, ...
                                                   innovations.positive_var_indx, ...
                                                   x, ep.init, y0, oo.steady_state, ...
-                                                  0, ep.use_bytecode, ...
+                                                  0, ...
                                                   ep.stochastic.order, M, ...
                                                   pfm, ep.stochastic.algo, ...
                                                   ep.solve_algo, ...
@@ -39,7 +39,7 @@ for i=1:length(nodes)
     [y2, info_convergence, endogenousvariablespaths] = ...
         extended_path_core(ep.periods, M.endo_nbr, M.exo_nbr, ...
                            innovations.positive_var_indx, x2, ep.init, ...
-                           y1, oo.steady_state, 0, ep.use_bytecode, ...
+                           y1, oo.steady_state, 0, ...
                            ep.stochastic.order, M, pfm, ep.stochastic.algo, ...
                            ep.solve_algo, ep.stack_solve_algo, options.lmmcp, ...
                            options, oo, []);
@@ -47,4 +47,4 @@ for i=1:length(nodes)
     z = [y0(i_pred); y1; y2(i_fwrd)];
     res(:,i) = dynamic_model(z,x,M.params,oo.steady_state,2);
 end
-e = res*weights;
\ No newline at end of file
+e = res*weights;
