@@ -46,6 +46,9 @@ options.nobs=mydata.nobs;
 label = mydata.shock_group.label;
 label = strrep(label,' ','_');
 label = strrep(label,'-','_');
+label = strrep(label,'(','');
+label = strrep(label,')','');
+label = strrep(label,'.','');
 shocks = mydata.shock_group.shocks;
 options.plot_shock_decomp.fig_name = [mydata.fig_name '. Expand'];
 options.plot_shock_decomp.use_shock_groups = label; %[use_shock_groups_old int2str(ic)];
