@@ -26,7 +26,7 @@ function global_initialization()
 % GNU General Public License for more details.
 %
 % You should have received a copy of the GNU General Public License
-% along with Dynare.  If not, see <http://www.gnu.org/licenses/>.
+% along with Dynare.  If not, see <https://www.gnu.org/licenses/>.
 
 global oo_ M_ options_ estim_params_ bayestopt_ estimation_info ex0_ ys0_ dataset_ dataset_info
 estim_params_ = [];
@@ -92,6 +92,7 @@ oo_.dr = [];
 oo_.exo_steady_state = [];
 oo_.exo_det_steady_state = [];
 oo_.exo_det_simul = [];
+oo_.initval_series = dseries();
 
 oo_.gui.ran_estimation = false;
 oo_.gui.ran_stoch_simul = false;
@@ -143,12 +144,18 @@ dyn_first_order_solver();
 % Set dynare random generator and seed.
 set_dynare_seed('default');
 
-
-% Create directories
-[~,~]=mkdir(M_.fname);
-[~,~]=mkdir([M_.fname filesep 'Output']);
-
 % Load user configuration file.
 if isfield(options_, 'global_init_file')
-    run(options_.global_init_file);
+    if isfile(options_.global_init_file)
+        try
+            run(options_.global_init_file);
+        catch
+            error('Cannot evaluate global initialization file (%s)', options_.global_init_file)
+        end
+    else
+        error('Cannot find global initialization file (%s).', options_.global_init_file)
+    end
 end
+
+end
+
