@@ -2,19 +2,21 @@ function [ldens,Dldens,D2ldens] = lpdfgbeta(x,a,b,aa,bb)
 % Evaluates the logged BETA PDF at x.
 %
 % INPUTS
-%    x     [double]  m*n matrix of loactions,
+%    x     [double]  m*n matrix of locations,
 %    a     [double]  m*n matrix of First BETA distribution parameters,
 %    b     [double]  m*n matrix of Second BETA distribution parameters,
 %    aa    [double]  m*n matrix of lower bounds for (generalized) distribution,
 %    bb    [double]  m*n matrix of upper bounds for (generalized) distribution
 %
 % OUTPUTS
-%    ldens [double]  m*n matrix of logged (generalized) BETA densities.
+%    ldens   [double]  m*n matrix of logged (generalized) BETA densities.
+%    Dldens  [double]  m*n matrix of first derivatives of logged (generalized) BETA densities.
+%    D2ldens [double]  m*n matrix of second derivatives of logged  matrix of logged (generalized) BETA densities.
 %
 % SPECIAL REQUIREMENTS
 %    none
 
-% Copyright (C) 2003-2017 Dynare Team
+% Copyright (C) 2003-2021 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -29,7 +31,7 @@ function [ldens,Dldens,D2ldens] = lpdfgbeta(x,a,b,aa,bb)
 % GNU General Public License for more details.
 %
 % You should have received a copy of the GNU General Public License
-% along with Dynare.  If not, see <http://www.gnu.org/licenses/>.
+% along with Dynare.  If not, see <https://www.gnu.org/licenses/>.
 
 ldens = -Inf( size(x) ) ;
 idx = find( (x-aa)>0 & (x-bb)<0 ) ;
@@ -42,6 +44,7 @@ end
 
 
 if nargout >1
+    Dldens = ldens ;
     if length(a)==1
         Dldens(idx) = (a-1)./(x(idx)-aa) - (b-1)./(bb-x(idx)) ;
     else
@@ -51,6 +54,7 @@ end
 
 
 if nargout == 3
+    D2ldens = ldens ;
     if length(a)==1
         D2ldens(idx) = -(a-1)./(x(idx)-aa).^2 - (b-1)./(bb-x(idx)).^2 ;
     else
