@@ -341,6 +341,9 @@ while notsteady && t<smpl
             varargout{2} = [];
             varargout{3} = [];
             varargout{4} = [];
+            varargout{5} = [];
+            varargout{6} = [];
+            varargout{7} = [];
             return
         end
 
@@ -363,6 +366,7 @@ while notsteady && t<smpl
         P(:,:,t) = Px(:,:,1);
         P1(:,:,t) = P1x(:,:,2);
         P(:,:,t+1) = Px(:,:,2);
+        aK(1,:,t+1) = a1(:,t+1);
         for jnk=1:nk
             PK(jnk,:,:,t+jnk) = Px(:,:,1+jnk);
             aK(jnk,:,t+jnk) = ax(:,1+jnk);
@@ -433,7 +437,7 @@ while notsteady && t<smpl
             Pf          = P(:,:,t+1);
         end
         aK(1,:,t+1) = a1(:,t+1);
-        if ~isempty(nk) && nk>1 && isoccbin 
+        if ~isempty(nk) && nk>1 && isoccbin && (t>=first_period_occbin_update || isinf(first_period_occbin_update))
             opts_simul = occbin_options.opts_regime;
             opts_simul.SHOCKS = zeros(nk,M_.exo_nbr);
             if smoother_redux
@@ -455,14 +459,16 @@ while notsteady && t<smpl
                 end
                 PK(jnk,:,:,t+jnk) = Pf;
             end
-            if isoccbin 
-                if smoother_redux
-                    aK(jnk,:,t+jnk) = out.piecewise(jnk,oo_.dr.order_var(oo_.dr.restrict_var_list));
+            if jnk>1
+                if isoccbin && (t>=first_period_occbin_update || isinf(first_period_occbin_update))
+                    if smoother_redux
+                        aK(jnk,:,t+jnk) = out.piecewise(jnk,oo_.dr.order_var(oo_.dr.restrict_var_list)) - out.ys(oo_.dr.order_var(oo_.dr.restrict_var_list))';
+                    else
+                        aK(jnk,oo_.dr.inv_order_var,t+jnk) = out.piecewise(jnk,:) - out.ys';
+                    end
                 else
-                    aK(jnk,oo_.dr.inv_order_var,t+jnk) = out.piecewise(jnk,:);
+                    aK(jnk,:,t+jnk) = T*dynare_squeeze(aK(jnk-1,:,t+jnk-1));
                 end
-            elseif jnk>1
-                aK(jnk,:,t+jnk) = T*dynare_squeeze(aK(jnk-1,:,t+jnk-1));
             end
         end
     end
@@ -486,6 +492,9 @@ varargout{1} = regimes_;
 varargout{2} = TTT;
 varargout{3} = RRR;
 varargout{4} = CCC;
+varargout{5} = TT;
+varargout{6} = RR;
+varargout{7} = CC;
 % $$$ P_s=tril(P(:,:,t))+tril(P(:,:,t),-1)';
 % $$$ P1_s=tril(P1(:,:,t))+tril(P1(:,:,t),-1)';
 % $$$ Fi_s = Fi(:,t);
