@@ -15,7 +15,7 @@ function r = subsref(o, S) % --*-- Unitary tests --*--
 %                     by applying a public method on `o`, or a dseries object built by extracting
 %                     a variable from `o`, or a dseries object containing a subsample.
 
-% Copyright (C) 2011-2020 Dynare Team
+% Copyright (C) 2011-2022 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -451,9 +451,9 @@ return
      t(2) = 0;
  end
  try
-     warning off all
+     warnstate = warning('off');
      c = ts1{'[A-Z]_1'};
-     warning on all
+     warning(warnstate);
      t(3) = 0;
  catch
      t(3) = 1;
@@ -769,4 +769,4 @@ return
  end
 
  T = all(t);
-%@eof:21
\ No newline at end of file
+%@eof:21
