@@ -8,7 +8,7 @@ function o = ydiff(o) % --*-- Unitary tests --*--
 % OUTPUTS
 % - o   [dseries]
 
-% Copyright (C) 2012-2017 Dynare Team
+% Copyright © 2012-2020 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -23,29 +23,31 @@ function o = ydiff(o) % --*-- Unitary tests --*--
 % GNU General Public License for more details.
 %
 % You should have received a copy of the GNU General Public License
-% along with Dynare.  If not, see <http://www.gnu.org/licenses/>.
+% along with Dynare.  If not, see <https://www.gnu.org/licenses/>.
 
 o = copy(o);
 o.ydiff_();
 
+return
+
 %@test:1
-%$ try
-%$     data = transpose(1:100);
-%$     ts = dseries(data,'1950Q1',{'A1'},{'A_1'});
-%$     ds = ts.ydiff();
-%$     t(1) = true;
-%$ catch
-%$     t(1) = false;
-%$ end
-%$
-%$
-%$ if t(1)
-%$     DATA = NaN(4,ts.vobs);
-%$     DATA = [DATA; 4*ones(ts.nobs-4,ts.vobs)];
-%$     t(2) = dassert(ds.data,DATA);
-%$     t(3) = dassert(ds.ops{1},['ydiff(A1)']);
-%$     t(4) = dassert(ts.data, data);
-%$ end
-%$
-%$ T = all(t);
+try
+    data = transpose(1:100);
+    ts = dseries(data,'1950Q1',{'A1'},{'A_1'});
+    ds = ts.ydiff();
+    t(1) = true;
+catch
+    t(1) = false;
+end
+
+
+if t(1)
+    DATA = NaN(4,ts.vobs);
+    DATA = [DATA; 4*ones(ts.nobs-4,ts.vobs)];
+    t(2) = dassert(ds.data,DATA);
+    t(3) = dassert(ds.ops{1},['ydiff(A1)']);
+    t(4) = dassert(ts.data, data);
+end
+
+T = all(t);
 %@eof:1
\ No newline at end of file
