@@ -16,8 +16,15 @@ function [hasPackage] = user_has_octave_forge_package(package)
 % GNU General Public License for more details.
 %
 % You should have received a copy of the GNU General Public License
-% along with Dynare.  If not, see <http://www.gnu.org/licenses/>.
+% along with Dynare.  If not, see <https://www.gnu.org/licenses/>.
 
 [desc,flag] = pkg('describe', package);
 
-hasPackage = isequal(flag{1,1}, 'Loaded');
\ No newline at end of file
+if isequal(flag{1,1}, 'Not installed')
+    hasPackage = 0;
+else
+    if isequal(flag{1,1}, 'Not loaded')
+        pkg('load', package);
+    end
+    hasPackage = 1;
+end
