@@ -1,6 +1,6 @@
 function runalltests()
 
-% Copyright (C) 2015-2019 Dynare Team
+% Copyright (C) 2015-2022 Dynare Team
 %
 % This code is free software: you can redistribute it and/or modify
 % it under the terms of the GNU General Public License as published by
@@ -40,7 +40,7 @@ catch
     initialize_dseries_class();
 end
 
-warning off
+warnstate = warning('off');
 
 if isoctave()
     if ~user_has_octave_forge_package('io')
@@ -60,7 +60,7 @@ else
     system('touch pass');
 end
 
-warning on
+warning(warnstate);
 path(opath);
 
 display_report(r);
