@@ -1,7 +1,7 @@
 classdef page < handle
     % page Class
     %
-    % Copyright (C) 2013-2019 Dynare Team
+    % Copyright (C) 2013-2022 Dynare Team
     %
     % This file is part of Dynare.
     %
@@ -65,9 +65,13 @@ classdef page < handle
             end
 
             % Octave 5.1.0 has not implemented `properties` and issues a warning when using `fieldnames`
-            warning('off')
+            if isoctave
+                warnstate = warning('off', 'Octave:classdef-to-struct');
+            end
             optNames = fieldnames(o);
-            warning('on')
+            if isoctave
+                warning(warnstate);
+            end
 
             % overwrite default values
             for pair = reshape(varargin, 2, [])
