@@ -28,7 +28,7 @@ function o = compile(o, varargin)
 % GNU General Public License for more details.
 %
 % You should have received a copy of the GNU General Public License
-% along with Dynare.  If not, see <http://www.gnu.org/licenses/>.
+% along with Dynare.  If not, see <https://www.gnu.org/licenses/>.
 
 opts.compiler = o.compiler;
 opts.showReport = true;
@@ -79,7 +79,9 @@ if isempty(opts.compiler)
         middle = ' ';
         opts.compiler = ['"' strtrim(opts.compiler) '"'];
     elseif isunix
-        [status, opts.compiler] = system('which pdflatex');
+        % “which” has been deprecated in Debian Bookworm; rather use “command -v”
+        % which should work with any reasonably recent GNU/Linux shell
+        [status, opts.compiler] = system('command -v pdflatex');
     end
     assert(status == 0, ...
            '@report.compile: Could not find a tex compiler on your system');
@@ -131,4 +133,4 @@ if status ~= 0
     error(['@report.compile: There was an error in compiling ' rfn '.pdf.' ...
         '  ' opts.compiler ' returned the error code: ' num2str(status)]);
 end
-end
\ No newline at end of file
+end
