@@ -14,7 +14,7 @@ function [options_, oo_]=ms_variance_decomposition(M_, options_, oo_)
 % SPECIAL REQUIREMENTS
 %    none
 
-% Copyright (C) 2011-2017 Dynare Team
+% Copyright (C) 2011-2020 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -29,7 +29,7 @@ function [options_, oo_]=ms_variance_decomposition(M_, options_, oo_)
 % GNU General Public License for more details.
 %
 % You should have received a copy of the GNU General Public License
-% along with Dynare.  If not, see <http://www.gnu.org/licenses/>.
+% along with Dynare.  If not, see <https://www.gnu.org/licenses/>.
 
 disp('MS-SBVAR Variance Decomposition');
 options_ = set_file_tags(options_);
@@ -78,8 +78,7 @@ if options_.ms.error_bands
 end
 
 % variance_decomposition
-[err] = ms_sbvar_command_line(opt);
-mexErrCheck('ms_variance_decomposition',err);
+ms_sbvar_command_line(opt);
 
 if options_.ms.regime || options_.ms.regimes
     outfile = [outfile 'regime_'];
