@@ -42,7 +42,7 @@ function [fh,xh,gh,H,itct,fcount,retcodeh] = csminwel1(fcn,x0,H0,grad,crit,nit,m
 % http://sims.princeton.edu/yftp/optimize/mfiles/csminwel.m
 %
 % Copyright (C) 1993-2007 Christopher Sims
-% Copyright (C) 2006-2017 Dynare Team
+% Copyright (C) 2006-2021 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -57,7 +57,7 @@ function [fh,xh,gh,H,itct,fcount,retcodeh] = csminwel1(fcn,x0,H0,grad,crit,nit,m
 % GNU General Public License for more details.
 %
 % You should have received a copy of the GNU General Public License
-% along with Dynare.  If not, see <http://www.gnu.org/licenses/>.
+% along with Dynare.  If not, see <https://www.gnu.org/licenses/>.
 
 % initialize variable penalty
 penalty = 1e8;
@@ -79,6 +79,9 @@ if ischar(fcn)
 end
 if ischar(grad)
     grad = str2func(grad);
+    grad_fun_provided = true;
+else
+    grad_fun_provided = false;
 end
 %tailstr = ')';
 %stailstr = [];
@@ -100,7 +103,7 @@ end
 
 if NumGrad
     [g, badg]=get_num_grad(method,fcn,penalty,f0,x0,epsilon,varargin{:});
-elseif ischar(grad)
+elseif grad_fun_provided
     [g,badg] = grad(x0,varargin{:});
 else
     g=arg1;
@@ -139,7 +142,7 @@ while ~done
         else
             if NumGrad
                 [g1, badg1]=get_num_grad(method,fcn,penalty,f1,x1,epsilon,varargin{:});
-            elseif ischar(grad)
+            elseif grad_fun_provided
                 [g1, badg1] = grad(x1,varargin{:});
             else
                 [~,cost_flag,g1] = penalty_objective_function(x1,fcn,penalty,varargin{:});
@@ -166,7 +169,7 @@ while ~done
                 else
                     if NumGrad
                         [g2, badg2]=get_num_grad(method,fcn,penalty,f2,x2,epsilon,varargin{:});
-                    elseif ischar(grad)
+                    elseif grad_fun_provided
                         [g2, badg2] = grad(x2,varargin{:});
                     else
                         [~,cost_flag,g2] = penalty_objective_function(x1,fcn,penalty,varargin{:});
@@ -198,7 +201,7 @@ while ~done
                         else
                             if NumGrad
                                 [g3, badg3]=get_num_grad(method,fcn,penalty,f3,x3,epsilon,varargin{:});
-                            elseif ischar(grad)
+                            elseif grad_fun_provided
                                 [g3, badg3] = grad(x3,varargin{:});
                             else
                                 [~,cost_flag,g3] = penalty_objective_function(x1,fcn,penalty,varargin{:});
@@ -225,16 +228,16 @@ while ~done
         f2=f;f3=f;f1=f;retcode2=retcode1;retcode3=retcode1;
     end
     %how to pick gh and xh
-    if f3 < f - crit && badg3==0 && f3 < f2 && f3 < f1
+    if f3 < f - crit && badg3==0 && f3 < f2 && f3 < f1  %f3 has improved function, gradient is good and it is smaller than the other two
         ih=3;
         fh=f3;xh=x3;gh=g3;badgh=badg3;retcodeh=retcode3;
-    elseif f2 < f - crit && badg2==0 && f2 < f1
+    elseif f2 < f - crit && badg2==0 && f2 < f1         %f2 has improved function, gradient is good and it is smaller than f2
         ih=2;
         fh=f2;xh=x2;gh=g2;badgh=badg2;retcodeh=retcode2;
-    elseif f1 < f - crit && badg1==0
+    elseif f1 < f - crit && badg1==0                    %f1 has improved function, gradient is good
         ih=1;
         fh=f1;xh=x1;gh=g1;badgh=badg1;retcodeh=retcode1;
-    else
+    else                                                % stuck or bad gradient
         [fh,ih] = min([f1,f2,f3]);
         %disp_verbose(sprintf('ih = %d',ih))
         %eval(['xh=x' num2str(ih) ';'])
@@ -250,22 +253,19 @@ while ~done
             %eval(['retcodeh=retcode' num2str(ih) ';'])
         retcodei=[retcode1,retcode2,retcode3];
         retcodeh=retcodei(ih);
-        if exist('gh')
-            nogh=isempty(gh);
-        else
-            nogh=1;
-        end
-        if nogh
+        
+        nogh=isempty(gh);        
+        badgh=1;
+        if nogh %recompute gradient
             if NumGrad
                 [gh, badgh]=get_num_grad(method,fcn,penalty,fh,xh,epsilon,varargin{:});
-            elseif ischar(grad)
+            elseif grad_fun_provided
                 [gh, badgh] = grad(xh,varargin{:});
             else
                 [~,cost_flag,gh] = penalty_objective_function(x1,fcn,penalty,varargin{:});
                 badgh = ~cost_flag;
             end
         end
-        badgh=1;
     end
     %end of picking
     stuck = (abs(fh-f) < crit);
