@@ -1,5 +1,5 @@
-function [xparam1, hh, gg, fval, igg, hess_info] = newrat(func0, x, bounds, analytic_derivation, ftol0, nit, flagg, Verbose, Save_files, hess_info, varargin)
-%  [xparam1, hh, gg, fval, igg, hess_info] = newrat(func0, x, bounds, analytic_derivation, ftol0, nit, flagg, Verbose, Save_files, hess_info, varargin)
+function [xparam1, hh, gg, fval, igg, hess_info] = newrat(func0, x, bounds, analytic_derivation, ftol0, nit, flagg, Verbose, Save_files, hess_info, prior_std, gradient_epsilon, parameter_names, varargin)
+%  [xparam1, hh, gg, fval, igg, hess_info] = newrat(func0, x, bounds, analytic_derivation, ftol0, nit, flagg, Verbose, Save_files, hess_info, gradient_epsilon, parameter_names, varargin)
 %
 %  Optimiser with outer product gradient and with sequences of univariate steps
 %  uses Chris Sims subroutine for line search
@@ -8,6 +8,7 @@ function [xparam1, hh, gg, fval, igg, hess_info] = newrat(func0, x, bounds, anal
 %  - func0                  name of the function that also outputs the single contributions at times t=1,...,T
 %                           of the log-likelihood to compute outer product gradient
 %  - x                      starting guess
+%  - bounds                 prior bounds of parameters 
 %  - analytic_derivation    1 if analytic derivatives, 0 otherwise
 %  - ftol0                  termination criterion for function change
 %  - nit                    maximum number of iterations
@@ -21,7 +22,12 @@ function [xparam1, hh, gg, fval, igg, hess_info] = newrat(func0, x, bounds, anal
 %  - Save_files             1 if intermediate output is to be saved
 %  - hess_info              structure storing the step sizes for
 %                           computation of Hessian
-%  - varargin               other inputs:
+%  - prior_std              prior standard devation of parameters (can be NaN); 
+%                           passed to mr_hessian
+%  - gradient_epsilon       [double] step size in gradient
+%  - parameter_names        [cell] names of parameters for error messages
+%  - varargin               other inputs
+%                           e.g. in dsge_likelihood and others:
 %                           varargin{1} --> DynareDataset
 %                           varargin{2} --> DatasetInfo
 %                           varargin{3} --> DynareOptions
@@ -54,7 +60,7 @@ function [xparam1, hh, gg, fval, igg, hess_info] = newrat(func0, x, bounds, anal
 % GNU General Public License for more details.
 %
 % You should have received a copy of the GNU General Public License
-% along with Dynare.  If not, see <http://www.gnu.org/licenses/>.
+% along with Dynare.  If not, see <https://www.gnu.org/licenses/>.
 
 % initialize variable penalty
 penalty = 1e8;
@@ -64,12 +70,11 @@ nx=length(x);
 xparam1=x;
 %ftol0=1.e-6;
 htol_base = max(1.e-7, ftol0);
-flagit=0;  % mode of computation of hessian in each iteration
+flagit=0;  % mode of computation of hessian in each iteration; hard-coded outer-product of gradients as it performed best in tests
 ftol=ftol0;
 gtol=1.e-3;
 htol=htol_base;
 htol0=htol_base;
-gibbstol=length(varargin{6}.pshape)/50; %25;
 
 % force fcn, grad to function handle
 if ischar(func0)
@@ -79,13 +84,17 @@ end
 % func0 = str2func([func2str(func0),'_hh']);
 % func0 = func0;
 [fval0,exit_flag,gg,hh]=penalty_objective_function(x,func0,penalty,varargin{:});
+if ~exit_flag
+    disp_verbose('Bad initial parameter.',Verbose)
+    return
+end
 fval=fval0;
 
 % initialize mr_gstep and mr_hessian
 
 outer_product_gradient=1;
 if isempty(hh)
-    [dum, gg, htol0, igg, hhg, h1, hess_info]=mr_hessian(x,func0,penalty,flagit,htol,hess_info,varargin{:});
+    [dum, gg, htol0, igg, hhg, h1, hess_info]=mr_hessian(x,func0,penalty,flagit,htol,hess_info,bounds,prior_std,Save_files,varargin{:});
     if isempty(dum)
         outer_product_gradient=0;
         igg = 1e-4*eye(nx);
@@ -112,15 +121,16 @@ else
     h1=[];
 end
 H = igg;
-disp_verbose(['Gradient norm ',num2str(norm(gg))],Verbose)
-ee=eig(hh);
-disp_verbose(['Minimum Hessian eigenvalue ',num2str(min(ee))],Verbose)
-disp_verbose(['Maximum Hessian eigenvalue ',num2str(max(ee))],Verbose)
+if Verbose
+    disp_eigenvalues_gradient(gg,hh);   
+end
 g=gg;
 check=0;
-if max(eig(hh))<0
-    disp_verbose('Negative definite Hessian! Local maximum!',Verbose)
-    pause
+if Verbose
+    if max(eig(hh))<0
+        disp('Negative definite Hessian! Local maximum!')
+        pause
+    end
 end
 if Save_files
     save('m1.mat','x','hh','g','hhg','igg','fval0')
@@ -130,7 +140,9 @@ igrad=1;
 igibbs=1;
 inx=eye(nx);
 jit=0;
-nig=[];
+if Save_files
+    nig=[];
+end
 ig=ones(nx,1);
 ggx=zeros(nx,1);
 while norm(gg)>gtol && check==0 && jit<nit
@@ -151,22 +163,25 @@ while norm(gg)>gtol && check==0 && jit<nit
         fval=fval1;
         x0=x01;
     end
-    if length(find(ig))<nx
-        ggx=ggx*0;
-        ggx(find(ig))=gg(find(ig));
+    ig_pos=find(ig);
+    if length(ig_pos)<nx
+        ggx=ggx*0;        
+        ggx(ig_pos)=gg(ig_pos);
         if analytic_derivation || ~outer_product_gradient
             hhx=hh;
         else
             hhx = reshape(dum,nx,nx);
         end
         iggx=eye(length(gg));
-        iggx(find(ig),find(ig)) = inv( hhx(find(ig),find(ig)) );
+        iggx(ig_pos,ig_pos) = inv( hhx(ig_pos,ig_pos) );
         [fvala,x0,fc,retcode] = csminit1(func0,x0,penalty,fval,ggx,0,iggx,Verbose,varargin{:});
     end
     x0 = check_bounds(x0,bounds);
-    [fvala, x0, ig] = mr_gstep(h1,x0,bounds,func0,penalty,htol0,Verbose,Save_files,varargin{:});
+    [fvala, x0, ig] = mr_gstep(h1,x0,bounds,func0,penalty,htol0,Verbose,Save_files,gradient_epsilon, parameter_names,varargin{:});
     x0 = check_bounds(x0,bounds);
-    nig=[nig ig];
+    if Save_files
+        nig=[nig ig];
+    end
     disp_verbose('Sequence of univariate steps!!',Verbose)
     fval=fvala;
     if (fval0(icount)-fval)<ftol && flagit==0
@@ -203,7 +218,7 @@ while norm(gg)>gtol && check==0 && jit<nit
             if flagit==2
                 hh=hh0;
             elseif flagg>0
-                [dum, gg, htol0, igg, hhg, h1, hess_info]=mr_hessian(xparam1,func0,penalty,flagg,ftol0,hess_info,varargin{:});
+                [dum, gg, htol0, igg, hhg, h1, hess_info]=mr_hessian(xparam1,func0,penalty,flagg,ftol0,hess_info,bounds,prior_std,Save_files,varargin{:});
                 if flagg==2
                     hh = reshape(dum,nx,nx);
                     ee=eig(hh);
@@ -215,15 +230,14 @@ while norm(gg)>gtol && check==0 && jit<nit
                 end
             end
         end
-        disp_verbose(['Actual dxnorm ',num2str(norm(x(:,end)-x(:,end-1)))],Verbose)
-        disp_verbose(['FVAL          ',num2str(fval)],Verbose)
-        disp_verbose(['Improvement   ',num2str(fval0(icount)-fval)],Verbose)
-        disp_verbose(['Ftol          ',num2str(ftol)],Verbose)
-        disp_verbose(['Htol          ',num2str(max(htol0))],Verbose)
-        disp_verbose(['Gradient norm  ',num2str(norm(gg))],Verbose)
-        ee=eig(hh);
-        disp_verbose(['Minimum Hessian eigenvalue ',num2str(min(ee))],Verbose)
-        disp_verbose(['Maximum Hessian eigenvalue ',num2str(max(ee))],Verbose)
+        if Verbose
+            disp(['Actual dxnorm ',num2str(norm(x(:,end)-x(:,end-1)))])
+            disp(['FVAL          ',num2str(fval)])
+            disp(['Improvement   ',num2str(fval0(icount)-fval)])
+            disp(['Ftol          ',num2str(ftol)])
+            disp(['Htol          ',num2str(max(htol0))])
+            disp_eigenvalues_gradient(gg,hh);
+        end
         g(:,icount+1)=gg;
     else
         df = fval0(icount)-fval;
@@ -243,7 +257,7 @@ while norm(gg)>gtol && check==0 && jit<nit
                     save('m1.mat','x','fval0','nig')
                 end
             end
-            [dum, gg, htol0, igg, hhg, h1, hess_info]=mr_hessian(xparam1,func0,penalty,flagit,htol,hess_info,varargin{:});
+            [dum, gg, htol0, igg, hhg, h1, hess_info]=mr_hessian(xparam1,func0,penalty,flagit,htol,hess_info,bounds,prior_std,Save_files,varargin{:});
             if isempty(dum)
                 outer_product_gradient=0;
             end
@@ -275,13 +289,11 @@ while norm(gg)>gtol && check==0 && jit<nit
             hhg=hh;
             H = inv(hh);
         end
-        disp_verbose(['Gradient norm  ',num2str(norm(gg))],Verbose)
-        ee=eig(hh);
-        disp_verbose(['Minimum Hessian eigenvalue ',num2str(min(ee))],Verbose)
-        disp_verbose(['Maximum Hessian eigenvalue ',num2str(max(ee))],Verbose)
-        if max(eig(hh))<0
-            disp_verbose('Negative definite Hessian! Local maximum!',Verbose)
-            pause(1)
+        if Verbose
+            if max(eig(hh))<0
+                disp('Negative definite Hessian! Local maximum!')
+                pause(1)
+            end
         end
         t=toc(tic1);
         disp_verbose(['Elapsed time for iteration ',num2str(t),' s.'],Verbose)
@@ -329,3 +341,10 @@ inx = find(x<=bounds(:,1));
 if ~isempty(inx)
     x(inx) = bounds(inx,1)+eps;
 end
+
+function ee=disp_eigenvalues_gradient(gg,hh)
+
+disp(['Gradient norm  ',num2str(norm(gg))])
+ee=eig(hh);
+disp(['Minimum Hessian eigenvalue ',num2str(min(ee))])
+disp(['Maximum Hessian eigenvalue ',num2str(max(ee))])
