@@ -14,9 +14,8 @@ function [x,f,exitflag,n_f_evals,n_grad_evals,n_constraint_evals,n_constraint_gr
 % fun       name of an M-file (M-function) which computes the value
 %           of the objective function <fun> at a point x,
 %           synopsis: f=fun(x)
-% grad      name of an M-file (M-function) which computes the gradient
+% grad      indicator whether objective function provides the gradient
 %           vector of the function <fun> at a point x,
-%           synopsis: g=grad(x)
 % func      name of an M-file (M-function) which computes the MAXIMAL
 %           RESIDUAL(!) for a set of constraints at a point x,
 %           synopsis: fc=func(x)
@@ -74,7 +73,7 @@ function [x,f,exitflag,n_f_evals,n_grad_evals,n_constraint_evals,n_constraint_gr
 % GNU General Public License for more details.
 %
 % You should have received a copy of the GNU General Public License
-% along with Dynare.  If not, see <http://www.gnu.org/licenses/>.
+% along with Dynare.  If not, see <https://www.gnu.org/licenses/>.
 
 
 
@@ -126,7 +125,7 @@ if nargin<2           % Function and/or starting point are not specified
 end
 if nargin<3
     app=1;             % No user-supplied gradients
-elseif isempty(grad)
+elseif isempty(grad) || grad==0
     app=1;
 else
     app=0;                     % Exact gradients are supplied
@@ -201,7 +200,7 @@ end
 epsnorm=1.e-15;
 epsnorm2=1.e-30;    % epsilon & epsilon^2
 
-if constr, h1=-1                  % NLP: restricted to minimization
+if constr, h1=-1;                  % NLP: restricted to minimization
     cnteps=optim.TolXConstraint;                % Max. admissible residual
 else
     h1=sign(optim.minimizer_indicator);         % Minimize resp. maximize a function
@@ -220,7 +219,7 @@ knorms=0; gnorms=zeros(1,10);    % Gradient norms stored
                                  %---}
 
 %Display control ---{
-if optim.verbosity<=0, dispdata=0
+if optim.verbosity<=0, dispdata=0;
     if optim.verbosity==-1
         dispwarn=0;
     else
@@ -271,9 +270,19 @@ stopf=0;
 
 % COMPUTE THE FUNCTION  ( FIRST TIME ) ----{
 if trx
-    f=feval(fun,x',varargin{:});
+    if app
+        f=feval(fun,x',varargin{:});
+    else
+        [f,g]=feval(fun,x',varargin{:});
+        n_grad_evals=n_grad_evals+1;
+    end    
 else
-    f=feval(fun,x,varargin{:});
+    if app
+        f=feval(fun,x,varargin{:});
+    else
+        [f,g]=feval(fun,x,varargin{:});
+        n_grad_evals=n_grad_evals+1;
+    end
 end
 n_f_evals=n_f_evals+1;
 if isempty(f)
@@ -311,7 +320,7 @@ elseif abs(f)==Inf
 end
 xrec=x; frec=f;     % record point and function value
                     % Constrained problem
-if constr,  fp=f; kless=0
+if constr,  fp=f; kless=0;
     if trx
         fc=feval(func,x');
     else
@@ -378,12 +387,7 @@ if app
     end
     n_f_evals=n_f_evals+n;
 else
-    if trx
-        g=feval(grad,x',varargin{:});
-    else
-        g=feval(grad,x,varargin{:});
-    end
-    n_grad_evals=n_grad_evals+1;
+    %done above
 end
 if size(g,2)==1, g=g'; end
 ng=norm(g);
@@ -537,7 +541,7 @@ while 1
                 xx=x;
             end
             if kj==0
-                kd=4
+                kd=4;
             end
             kj=kj+1;  w=-.9; h=h*2;             % use large coef. of space dilation
             if kj>2*kd
@@ -570,7 +574,7 @@ while 1
         % RESETTING ----{
         if kcheck>1
             idx=find(abs(g)>ZeroGrad); numelem=size(idx,2);
-            if numelem>0, grbnd=epsnorm*numelem^2
+            if numelem>0, grbnd=epsnorm*numelem^2;
                 if all(abs(g1(idx))<=abs(g(idx))*grbnd) || nrmz==0
                     if dispwarn
                         disp(wrnmes)
@@ -674,6 +678,9 @@ while 1
                 end
                 if ksm || kc>=mxtc
                     exitflag=-3;
+                    % don't return with NaN or Inf despite error code
+                    x=x1;
+                    f=f1;                  
                     if trx
                         x=x';
                     end
@@ -786,15 +793,15 @@ while 1
             end
             n_f_evals=n_f_evals+n;
         else
-            if trx
-                g=feval(grad,x',varargin{:});
+            if trx                
+                [~,g]=feval(fun,x',varargin{:});
             else
-                g=feval(grad,x,varargin{:});
+                [~,g]=feval(fun,x,varargin{:});
             end
             n_grad_evals=n_grad_evals+1;
         end
         if size(g,2)==1
-            g=g'
+            g=g';
         end
         ng=norm(g);
         if isnan(ng)
@@ -919,7 +926,7 @@ while 1
         % DISPLAY THE CURRENT VALUES ----{
         if k==ld
             disp('Iter.# ..... Function ... Step Value ... Gradient Norm ');
-            disp(sprintf('%5i   %13.5e   %13.5e     %13.5e',k,f,dx,ng));
+            fprintf('%5i   %13.5e   %13.5e     %13.5e\n',k,f,dx,ng);
             ld=k+dispdata;
         end
         %----}
@@ -934,7 +941,7 @@ while 1
             termflag=0;
         end
         if knan
-            termflag=0
+            termflag=0;
         end
         if kc>=mxtc
             termflag=0;
@@ -1084,7 +1091,7 @@ while 1
                     elseif isnan(f)
                         if dispwarn
                             disp(errmes)
-                            disp(error32)
+                            disp(error31)
                         end
                         exitflag=-3;
                         if trx
@@ -1105,9 +1112,9 @@ while 1
                         n_f_evals=n_f_evals+n;
                     else
                         if trx
-                            g=feval(grad,x',varargin{:});
+                            [~,g]=feval(fun,x',varargin{:});
                         else
-                            g=feval(grad,x,varargin{:});
+                            [~,g]=feval(fun,x,varargin{:});
                         end
                         n_grad_evals=n_grad_evals+1;
                     end
@@ -1210,9 +1217,9 @@ while 1
                         n_f_evals=n_f_evals+n;
                     else
                         if trx
-                            gt=feval(grad,x1',varargin{:});
+                            [~,gt]=feval(fun,x1',varargin{:});
                         else
-                            gt=feval(grad,x1,varargin{:});
+                            [~,gt]=feval(fun,x1,varargin{:});
                         end
                         n_grad_evals=n_grad_evals+1;
                     end
