@@ -28,7 +28,7 @@ function results = prior_sampler(drsave,M_,bayestopt_,options_,oo_,estim_params_
 % GNU General Public License for more details.
 %
 % You should have received a copy of the GNU General Public License
-% along with Dynare.  If not, see <http://www.gnu.org/licenses/>.
+% along with Dynare.  If not, see <https://www.gnu.org/licenses/>.
 
 % Initialization.
 prior_draw(bayestopt_, options_.prior_trunc);
@@ -96,7 +96,7 @@ while iteration < NumberOfSimulations
     loop_indx = loop_indx+1;
     params = prior_draw();
     M_ = set_all_parameters(params,estim_params_,M_);
-    [T,R,~,INFO,M_,options_,oo_] = dynare_resolve(M_,options_,oo_,'restrict');
+    [T,R,~,INFO,M_,oo_] = dynare_resolve(M_,options_,oo_,'restrict');
     dr=oo_.dr;
     if ~INFO(1)
         INFO=endogenous_prior_restrictions(T,R,M_,options_,oo_);
