@@ -30,7 +30,7 @@ function [logged_prior_density, dlprior, d2lprior, info] = priordens(x, pshape,
 % GNU General Public License for more details.
 %
 % You should have received a copy of the GNU General Public License
-% along with Dynare.  If not, see <http://www.gnu.org/licenses/>.
+% along with Dynare.  If not, see <https://www.gnu.org/licenses/>.
 
 persistent id1 id2 id3 id4 id5 id6 id8
 persistent tt1 tt2 tt3 tt4 tt5 tt6 tt8
@@ -83,8 +83,8 @@ if nargin > 6  && initialization
 end
 
 logged_prior_density = 0.0;
-dlprior = 0.0;
-d2lprior = 0.0;
+dlprior = zeros(1,length(x));
+d2lprior = dlprior;
 
 if tt1
     logged_prior_density = logged_prior_density + sum(lpdfgbeta(x(id1),p6(id1),p7(id1),p3(id1),p4(id1))) ;
@@ -181,9 +181,9 @@ if tt8
         return
     end
     if nargout==2
-        [tmp, dlprior(id8)] = lpdfgweibull(x(id8),p6(id8),p7(id8))
+        [tmp, dlprior(id8)] = lpdfgweibull(x(id8),p6(id8),p7(id8));
     elseif nargout==3
-        [tmp, dlprior(id8), ds2lprior(id8)] = lpdfgweibull(x(id8),p6(id8),p7(id8))
+        [tmp, dlprior(id8), d2lprior(id8)] = lpdfgweibull(x(id8),p6(id8),p7(id8));
     end
 end
 
