@@ -84,8 +84,9 @@ end
 
 options_.selected_variables_only = 0; %make sure all variables are stored
 options_.plot_priors=0;
-[oo_, M_, ~, ~, Smoothed_Variables_deviation_from_mean] = evaluate_smoother(parameter_set, varlist, M_, oo_, options_, bayestopt_, estim_params_);
+[oo_, M_, ~, ~, Smoothed_Variables_deviation_from_mean, initial_date] = evaluate_smoother(parameter_set, varlist, M_, oo_, options_, bayestopt_, estim_params_);
 
+options_.initial_date=initial_date;
 % reduced form
 dr = oo_.dr;
 
