@@ -24,7 +24,7 @@ function smoother2histval(opts)
 %
 % The function also uses the value of option_.parameter_set
 
-% Copyright (C) 2014-2018 Dynare Team
+% Copyright (C) 2014-2021 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -39,7 +39,7 @@ function smoother2histval(opts)
 % GNU General Public License for more details.
 %
 % You should have received a copy of the GNU General Public License
-% along with Dynare.  If not, see <http://www.gnu.org/licenses/>.
+% along with Dynare.  If not, see <https://www.gnu.org/licenses/>.
 
 global M_ options_ oo_
 
@@ -49,7 +49,6 @@ if ~isfield(opts, 'infile')
     end
     smoothedvars = oo_.SmoothedVariables;
     smoothedshocks = oo_.SmoothedShocks;
-    steady_state = oo_.steady_state;
 else
     S = load(opts.infile);
     if ~isfield(S, 'oo_') || ~isfield(S.oo_, 'SmoothedVariables')
@@ -57,7 +56,6 @@ else
     end
     smoothedvars = S.oo_.SmoothedVariables;
     smoothedshocks = S.oo_.SmoothedShocks;
-    steady_state = S.oo_.steady_state;
 end
 
 % Hack to determine if oo_.SmoothedVariables was computed after a Metropolis
@@ -78,6 +76,11 @@ end
 
 if post_metropolis
     tmp = fieldnames(smoothedvars.Mean);
+    if length(tmp)~=M_.endo_nbr
+        warning(['You are using smoother2histval although smoothed values have not '...
+            'been computed for all endogenous and auxiliary variables.'...
+            'The value of these variables will be set to their steady state.'])
+    end
     tmpexo = fieldnames(smoothedshocks.Mean);
 else
     tmp = fieldnames(smoothedvars);
@@ -89,7 +92,6 @@ if isempty(options_.parameter_set)
     if post_metropolis
         smoothedvars = smoothedvars.Mean;
         smoothedshocks = smoothedshocks.Mean;
-        steady_state = zeros(size(steady_state));
     end
 else
     switch options_.parameter_set
@@ -107,21 +109,19 @@ else
         end
         smoothedvars = smoothedvars.Mean;
         smoothedshocks = smoothedshocks.Mean;
-        steady_state = zeros(size(steady_state));
       case 'posterior_median'
         if ~post_metropolis
             error('Option parameter_set=posterior_median is not consistent with computed smoothed values.')
         end
         smoothedvars = smoothedvars.Median;
         smoothedshocks = smoothedshocks.Median;
-        steady_state = zeros(size(steady_state));
       otherwise
         error([ 'Option parameter_set=' options_.parameter_set ' unsupported.' ])
     end
 end
 
 % Determine number of periods
-n = size(smoothedvars.(tmp{1}));
+n = length(smoothedvars.(tmp{1}));
 
 if n < M_.maximum_endo_lag
     error('Not enough observations to create initial conditions')
@@ -163,75 +163,100 @@ end
 % Initialize outputs
 if ~isfield(opts, 'outfile')
     % Output to M_.endo_histval
-    M_.endo_histval = repmat(oo_.steady_state, 1, M_.maximum_endo_lag);
+    M_.endo_histval = repmat(oo_.steady_state, 1, M_.maximum_lag);
 else
     % Output to a file
-    o = struct();
+    data = zeros(M_.maximum_endo_lag, length(invars));
+    for i=1:length(outvars)
+        j = strmatch(outvars{i}, M_.endo_names, 'exact');
+        if ~isempty(j)
+            data(:,i)=oo_.steady_state(j);
+        end
+    end
+    o = dseries();
 end
 
 % Handle all endogenous variables to be copied
 for i = 1:length(invars)
-    if isempty(strmatch(invars{i}, M_.endo_names))
-        % Skip exogenous
-        continue
-    end
-    s = smoothedvars.(invars{i});
-    j = strmatch(invars{i}, M_.endo_names, 'exact');
-    v = s((period-M_.maximum_endo_lag+1):period);% + steady_state(j);
-    if ~isfield(opts, 'outfile')
-        j = strmatch(outvars{i}, M_.endo_names, 'exact');
-        if isempty(j)
-            error(['smoother2histval: output variable ' outvars{i} ' does not exist.'])
+    if ~isempty(strmatch(invars{i}, M_.endo_names, 'exact')) 
+        if oo_.Smoother.loglinear
+            s = exp(smoothedvars.(invars{i}));
         else
-            M_.endo_histval(j, :) = v;
+            s = smoothedvars.(invars{i});
+        end
+    elseif ~isempty(strmatch(invars{i}, M_.exo_names, 'exact'))
+        s = smoothedshocks.(invars{i});
+    else
+        error('smoother2histval: unknown input variable')
+    end
+    
+    v = s((period-M_.maximum_lag+1):period);
+    if ~isfield(opts, 'outfile')
+        j_endo = strmatch(outvars{i}, M_.endo_names, 'exact');
+        if ~isempty(j_endo) 
+            M_.endo_histval(j_endo, :) = v;
+        end
+        j_exo = strmatch(outvars{i}, M_.exo_names, 'exact');
+        if ~isempty(j_exo)
+            M_.exo_histval(j_exo, :) = v;
+        end
+        if isempty(j_endo) && isempty(j_exo)
+            error(['smoother2histval: output variable ' outvars{i} ' does not exist.'])            
         end
     else
-        % When saving to a file, x(-1) is in the variable called "x_"
-        o.([ outvars{i} '_' ]) = v;
+        data(:, i) = v';
     end
 end
+if isfield(opts, 'outfile')
+    o = dseries(data, '1Y', invars);
+end
 
-% Handle auxiliary variables for lags (both on endogenous and exogenous)
-for i = 1:length(M_.aux_vars)
-    if ~ ismember(M_.endo_names{M_.aux_vars(i).endo_index},invars)
-        if M_.aux_vars(i).type ~= 1 && M_.aux_vars(i).type ~= 3
-            continue
-        end
-        if M_.aux_vars(i).type == 1
-            % Endogenous
-            orig_var = M_.endo_names{M_.aux_vars(i).orig_index};
-        else
-            % Exogenous
-            orig_var = M_.exo_names{M_.aux_vars(i).orig_index};
-        end
-        [m, k] = ismember(orig_var, outvars);
-        if m
-            if ~isempty(strmatch(invars{k}, M_.endo_names))
-                s = smoothedvars.(invars{k});
-            else
-                s = smoothedshocks.(invars{k});
-            end
-            l = M_.aux_vars(i).orig_lead_lag;
-            if period-M_.maximum_endo_lag+1+l < 1
-                error('The period that you indicated is too small to construct initial conditions')
-            end
-            j = M_.aux_vars(i).endo_index;
-            v = s((period-M_.maximum_endo_lag+1+l):(period+l)); %+steady_state(j);
-            if ~isfield(opts, 'outfile')
-                M_.endo_histval(j, :) = v;
-            else
-                % When saving to a file, x(-2) is in the variable called "x_l2"
-                lead_lag = num2str(l);
-                lead_lag = regexprep(lead_lag, '-', 'l');
-                o.([ orig_var '_' lead_lag ]) = v;
-            end
-        end
-    end
-end
+% $$$ % Handle auxiliary variables for lags (both on endogenous and exogenous)
+% $$$ for i = 1:length(M_.aux_vars)
+% $$$     if ~ ismember(M_.endo_names{M_.aux_vars(i).endo_index},invars)
+% $$$         if M_.aux_vars(i).type ~= 1 && M_.aux_vars(i).type ~= 3
+% $$$             continue
+% $$$         end
+% $$$         if M_.aux_vars(i).type == 1
+% $$$             % Endogenous
+% $$$             orig_var = M_.endo_names{M_.aux_vars(i).orig_index};
+% $$$         else
+% $$$             % Exogenous
+% $$$             orig_var = M_.exo_names{M_.aux_vars(i).orig_index};
+% $$$         end
+% $$$         [m, k] = ismember(orig_var, outvars);
+% $$$         if m
+% $$$             if ~isempty(strmatch(invars{k}, M_.endo_names))
+% $$$                 s = smoothedvars.(invars{k});
+% $$$             else
+% $$$                 s = smoothedshocks.(invars{k});
+% $$$             end
+% $$$             l = M_.aux_vars(i).orig_lead_lag;
+% $$$             if period-M_.maximum_endo_lag+1+l < 1
+% $$$                 error('The period that you indicated is too small to construct initial conditions')
+% $$$             end
+% $$$             j = M_.aux_vars(i).endo_index;
+% $$$             v = s((period-M_.maximum_endo_lag+1+l):(period+l)); %+steady_state(j);
+% $$$             if ~isfield(opts, 'outfile')
+% $$$                 M_.endo_histval(j, :) = v;
+% $$$             else
+% $$$                 % When saving to a file, x(-2) is in the variable called "x_l2"
+% $$$                 lead_lag = num2str(l);
+% $$$                 lead_lag = regexprep(lead_lag, '-', 'l');
+% $$$                 o.([ orig_var '_' lead_lag ]) = v;
+% $$$             end
+% $$$         end
+% $$$     end
+% $$$ end
 
 % Finalize output
 if isfield(opts, 'outfile')
-    save(opts.outfile, '-struct', 'o')
+    [dir, fname, ext] = fileparts(opts.outfile);
+    if ~strcmp(ext,'.mat') && ~isempty(ext)
+        error(['smoother2hisvtval: if outfile has an extension, it must ' ...
+               'be .mat'])
+    end
+    o.save([dir fname]);
 end
 
 end
