@@ -53,7 +53,7 @@ function [y, T, oo_, info] = solve_one_boundary(fname, y, x, params, steady_stat
 %   none.
 %
 
-% Copyright (C) 1996-2020 Dynare Team
+% Copyright (C) 1996-2022 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -73,6 +73,7 @@ function [y, T, oo_, info] = solve_one_boundary(fname, y, x, params, steady_stat
 
 Blck_size=size(y_index_eq,2);
 correcting_factor=0.01;
+ilu_setup.type='crout';
 ilu_setup.droptol=1e-10;
 max_resa=1e100;
 reduced = 0;
@@ -142,6 +143,14 @@ for it_=start:incr:finish
                                 if verbose
                                     disp('The singularity of the jacobian matrix could not be corrected')
                                 end
+                                if is_dynamic
+                                    oo_.deterministic_simulation.status = false;
+                                    oo_.deterministic_simulation.error = max_res;
+                                    oo_.deterministic_simulation.iterations = iter;
+                                    oo_.deterministic_simulation.block(Block_Num).status = false;% Convergency failed.
+                                    oo_.deterministic_simulation.block(Block_Num).error = max_res;
+                                    oo_.deterministic_simulation.block(Block_Num).iterations = iter;
+                                end
                                 info = -Block_Num*10;
                                 return
                             end
@@ -191,24 +200,19 @@ for it_=start:incr:finish
             ya_save=ya;
             g1a=g1;
             if is_dynamic && stack_solve_algo==4
-                lambda=1;
                 stpmx = 100 ;
-                if is_dynamic
-                    stpmax = stpmx*max([sqrt(ya'*ya);size(y_index_eq,2)]);
-                else
-                    stpmax = stpmx*max([sqrt(ya'*ya);size(y_index_eq,2)]);
-                end
+                stpmax = stpmx*max([sqrt(ya'*ya);size(y_index_eq,2)]);
                 nn=1:size(y_index_eq,2);
                 g = (r'*g1)';
                 f = 0.5*r'*r;
                 p = -g1\r ;
                 [ya,f,r,check]=lnsrch1(ya,f,g,p,stpmax, ...
                                        'lnsrch1_wrapper_one_boundary',nn, ...
-                                       y_index_eq, options.solve_tolx, M.lead_lag_incidence(M.maximum_endo_lag+1, :), fname, Block_Num, dynvars_from_endo_simul(y, it_, M), x, params, steady_state, T(:, it_), it_);
+                                       nn, options.solve_tolx, y_index_eq, fname, Block_Num, y, x, params, steady_state, T(:, it_), it_, M);
+                dx = ya - y(y_index_eq, it_);
+                y(y_index_eq, it_) = ya;
                 %% Recompute temporary terms, since they are not given as output of lnsrch1
                 [~, ~, T(:, it_)] = feval(fname, Block_Num, dynvars_from_endo_simul(y, it_, M), x, params, steady_state, T(:, it_), it_, false);
-                dx = ya' - y(index_eq, it_);
-                y(index_eq, it_) = ya;
             elseif (is_dynamic && (stack_solve_algo==1 || stack_solve_algo==0)) || (~is_dynamic && options.solve_algo==6)
                 if verbose && ~is_dynamic
                     disp('steady: Sparse LU ')
@@ -256,32 +260,15 @@ for it_=start:incr:finish
                 end
                 while flag1>0
                     [L1, U1]=ilu(g1,ilu_setup);
-                    phat = ya - U1 \ (L1 \ r);
-                    if is_dynamic
-                        y(y_index_eq, it_) = phat;
-                    else
-                        y(y_index_eq) = phat;
-                    end
-                    if is_dynamic
-                        [r, ~, T(:, it_), g1] = feval(fname, Block_Num, dynvars_from_endo_simul(y, it_, M), x, params, ...
-                                                   steady_state, T(:, it_), it_, false);
-                    else
-                        [r, ~, T, g1] = feval(fname, Block_Num, y, x, params, T);
-                    end
-                    if max(abs(r))>=options.solve_tolf
-                        [dx,flag1] = bicgstab(g1,-r,1e-7,Blck_size,L1,U1);
-                    else
-                        flag1 = 0;
-                        dx = phat - ya;
-                    end
+                    [dx,flag1] = bicgstab(g1,-r,1e-6,Blck_size,L1,U1);
                     if flag1>0 || reduced
                         if verbose
                             if(flag1==1)
-                                disp(['Error in simul: No convergence inside BICGSTAB after ' num2str(iter,'%6d') ' iterations, in block' num2str(Block_Num,'%3d')])
+                                disp(['Error in simul: No convergence inside BiCGStab after ' num2str(iter,'%6d') ' iterations, in block' num2str(Block_Num,'%3d')])
                             elseif(flag1==2)
                                 disp(['Error in simul: Preconditioner is ill-conditioned, in block' num2str(Block_Num,'%3d')])
                             elseif(flag1==3)
-                                disp(['Error in simul: GMRES stagnated (Two consecutive iterates were the same.), in block' num2str(Block_Num,'%3d')])
+                                disp(['Error in simul: BiCGStab stagnated (Two consecutive iterates were the same.), in block' num2str(Block_Num,'%3d')])
                             end
                         end
                         ilu_setup.droptol = ilu_setup.droptol/10;
@@ -296,16 +283,11 @@ for it_=start:incr:finish
                     end
                 end
             else
-                if verbose
-                    disp('unknown option : ')
-                    if is_dynamic
-                        disp(['options_.stack_solve_algo = ' num2str(stack_solve_algo) ' not implemented'])
-                    else
-                        disp(['options_.solve_algo = ' num2str(options.solve_algo) ' not implemented'])
-                    end
+                if is_dynamic
+                    error(['options_.stack_solve_algo = ' num2str(stack_solve_algo) ' not implemented'])
+                else
+                    error(['options_.solve_algo = ' num2str(options.solve_algo) ' not implemented'])
                 end
-                info = -Block_Num*10;
-                return
             end
             iter=iter+1;
             max_resa = max_res;
