@@ -1,6 +1,6 @@
 function [info, oo_, options_, M_] = stoch_simul(M_, options_, oo_, var_list)
 
-% Copyright (C) 2001-2020 Dynare Team
+% Copyright (C) 2001-2021 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -15,17 +15,34 @@ function [info, oo_, options_, M_] = stoch_simul(M_, options_, oo_, var_list)
 % GNU General Public License for more details.
 %
 % You should have received a copy of the GNU General Public License
-% along with Dynare.  If not, see <http://www.gnu.org/licenses/>.
+% along with Dynare.  If not, see <https://www.gnu.org/licenses/>.
 
 % Test if the order of approximation is nonzero (the preprocessor tests if order is non negative).
 if isequal(options_.order,0)
     error('stoch_simul:: The order of the Taylor approximation cannot be 0!')
 end
 
+% The TeX option crashes MATLAB R2014a run with "-nodisplay" option
+% (as is done from the testsuite).
+% Since we can’t directly test whether "-nodisplay" has been passed,
+% we test for the "TOP_TEST_DIR" environment variable, which is set
+% by the testsuite.
+% Note that it was not tested whether the crash happens with more
+% recent MATLAB versions, so when OLD_MATLAB_VERSION is increased,
+% one should make a test before removing this workaround.
+if options_.TeX && ~isoctave && matlab_ver_less_than('8.4') && ~isempty(getenv('TOP_TEST_DIR'))
+    warning('Disabling TeX option due to a bug in MATLAB R2014a with -nodisplay')
+    options_.TeX = false;
+end
+
 if M_.exo_nbr==0
     error('stoch_simul:: does not support having no varexo in the model. As a workaround you could define a dummy exogenous variable.')
 end
 
+if ismember(options_.solve_algo,[10,11])
+    error('stoch_simul:: perturbation solutions are not compatible with mixed complementarity problems and their solvers')
+end
+
 test_for_deep_parameters_calibration(M_);
 
 dr = oo_.dr;
@@ -79,17 +96,17 @@ oo_.dr=set_state_space(dr,M_,options_);
 if PI_PCL_solver
     [oo_.dr, info] = PCL_resol(oo_.steady_state,0);
 elseif options_.discretionary_policy
-    if ~options_.linear
+    if ~options_.order==1
         error('discretionary_policy: only linear-quadratic problems can be solved');
     end
-    [~,info,M_,options_,oo_] = discretionary_policy_1(options_.instruments,M_,options_,oo_);
+    [~,info,M_,oo_] = discretionary_policy_1(options_.instruments,M_,options_,oo_);
 else
     if options_.logged_steady_state %if steady state was previously logged, undo this
         oo_.dr.ys=exp(oo_.dr.ys);
         oo_.steady_state=exp(oo_.steady_state);
         options_.logged_steady_state=0;
     end
-    [~,info,M_,options_,oo_] = resol(0,M_,options_,oo_);
+    [~,info,M_,oo_] = resol(0,M_,options_,oo_);
 end
 
 if options_.loglinear && isfield(oo_.dr,'ys') && options_.logged_steady_state==0 %log steady state for correct display of decision rule
@@ -189,9 +206,11 @@ if ~options_.nomoments
     if PI_PCL_solver
         PCL_Part_info_moments(0, PCL_varobs, oo_.dr, i_var);
     elseif options_.periods == 0
-        % There is no code for theoretical moments at 3rd order
-        if options_.order <= 2
+        if options_.order == 1 || (options_.order == 2 && ~options_.pruning)
             oo_=disp_th_moments(oo_.dr,var_list,M_,options_,oo_);
+        elseif (ismember(options_.order,[2,3])) && options_.pruning  
+            % There is no code for theoretical moments at 3rd order without pruning
+            oo_=disp_th_moments_pruned_state_space(oo_.dr,M_,options_,i_var,oo_);
         end
     else
         oo_=disp_moments(oo_.endo_simul,var_list,M_,options_,oo_);
@@ -202,12 +221,12 @@ end
 if options_.irf
     var_listTeX = M_.endo_names_tex(i_var);
     if ~options_.nograph || (TeX && any(strcmp('eps',cellstr(options_.graph_format))))
-        if ~exist([M_.fname '/graphs'],'dir')
-            mkdir(M_.fname,'graphs');
+        if ~exist([M_.dname '/graphs'],'dir')
+            mkdir(M_.dname,'graphs');
         end
     end
     if TeX && any(strcmp('eps',cellstr(options_.graph_format)))
-        fidTeX = fopen([M_.fname, '/graphs/' M_.fname '_IRF.tex'],'w');
+        fidTeX = fopen([M_.dname, '/graphs/' M_.fname '_IRF.tex'],'w');
         fprintf(fidTeX,'%% TeX eps-loader file generated by stoch_simul.m (Dynare).\n');
         fprintf(fidTeX,['%% ' datestr(now,0) '\n']);
         fprintf(fidTeX,' \n');
@@ -292,16 +311,17 @@ if options_.irf
                         hold off
                         xlim([1 options_.irf]);
                         remove_fractional_xticks;
-                        title(deblank(mylist(j,:)),'Interpreter','none');
+                        if TeX
+                            title(['$' deblank(mylistTeX(j,:)) '$'],'Interpreter','latex');
+                        else
+                            title(deblank(mylist(j,:)),'Interpreter','none');
+                        end
                     end
-                    dyn_saveas(hh,[M_.fname, '/graphs/' M_.fname '_IRF_' tit{i}],options_.nodisplay,options_.graph_format);
+                    dyn_saveas(hh,[M_.dname, '/graphs/' M_.fname '_IRF_' tit{i}],options_.nodisplay,options_.graph_format);
                     if TeX && any(strcmp('eps',cellstr(options_.graph_format)))
                         fprintf(fidTeX,'\\begin{figure}[H]\n');
-                        for j = 1:number_of_plots_to_draw
-                            fprintf(fidTeX,'\\psfrag{%s}[1][][0.5][0]{$%s$}\n',deblank(mylist(j,:)),deblank(mylistTeX(j,:)));
-                        end
                         fprintf(fidTeX,'\\centering \n');
-                        fprintf(fidTeX,'\\includegraphics[width=%2.2f\\textwidth]{%s_IRF_%s}\n',options_.figures.textwidth*min(j/nc,1),[M_.fname, '/graphs/' M_.fname],tit{i});
+                        fprintf(fidTeX,'\\includegraphics[width=%2.2f\\textwidth]{%s_IRF_%s}\n',options_.figures.textwidth*min(j/nc,1),[M_.dname, '/graphs/' M_.fname],tit{i});
                         fprintf(fidTeX,'\\caption{Impulse response functions (orthogonalized shock to $%s$).}\n',titTeX{i});
                         fprintf(fidTeX,'\\label{Fig:IRF:%s}\n', tit{i});
                         fprintf(fidTeX,'\\end{figure}\n');
@@ -324,16 +344,17 @@ if options_.irf
                             hold off
                             xlim([1 options_.irf]);
                             remove_fractional_xticks
-                            title(deblank(mylist((fig-1)*nstar+plt,:)),'Interpreter','none');
+                            if TeX
+                                title(['$' deblank(mylistTeX((fig-1)*nstar+plt,:)) '$'],'Interpreter','latex');
+                            else
+                                title(deblank(mylist((fig-1)*nstar+plt,:)),'Interpreter','none');
+                            end
                         end
-                        dyn_saveas(hh,[M_.fname, '/graphs/'  M_.fname '_IRF_' tit{i} int2str(fig)],options_.nodisplay,options_.graph_format);
+                        dyn_saveas(hh,[M_.dname, '/graphs/'  M_.fname '_IRF_' tit{i} int2str(fig)],options_.nodisplay,options_.graph_format);
                         if TeX && any(strcmp('eps',cellstr(options_.graph_format)))
                             fprintf(fidTeX,'\\begin{figure}[H]\n');
-                            for j = 1:nstar
-                                fprintf(fidTeX,'\\psfrag{%s}[1][][0.5][0]{$%s$}\n',deblank(mylist((fig-1)*nstar+j,:)),deblank(mylistTeX((fig-1)*nstar+j,:)));
-                            end
                             fprintf(fidTeX,'\\centering \n');
-                            fprintf(fidTeX,'\\includegraphics[width=%2.2f\\textwidth]{%s_IRF_%s%s}\n',options_.figures.textwidth*min(plt/nc,1),[M_.fname, '/graphs/' M_.fname],tit{i},int2str(fig));
+                            fprintf(fidTeX,'\\includegraphics[width=%2.2f\\textwidth]{%s_IRF_%s%s}\n',options_.figures.textwidth*min(plt/nc,1),[M_.dname, '/graphs/' M_.fname],tit{i},int2str(fig));
                             if options_.relative_irf
                                 fprintf(fidTeX,'\\caption{Relative impulse response functions (orthogonalized shock to $%s$).}', titTeX{i});
                             else
@@ -355,16 +376,17 @@ if options_.irf
                         hold off
                         xlim([1 options_.irf]);
                         remove_fractional_xticks
-                        title(deblank(mylist((nbplt-1)*nstar+plt,:)),'Interpreter','none');
+                            if TeX
+                                title(['$' deblank(mylistTeX((nbplt-1)*nstar+plt,:)) '$'],'Interpreter','latex');
+                            else
+                                title(deblank(mylist((nbplt-1)*nstar+plt,:)),'Interpreter','none');
+                            end
                     end
-                    dyn_saveas(hh,[M_.fname, '/graphs/' M_.fname '_IRF_' tit{i} int2str(nbplt) ],options_.nodisplay,options_.graph_format);
+                    dyn_saveas(hh,[M_.dname, '/graphs/' M_.fname '_IRF_' tit{i} int2str(nbplt) ],options_.nodisplay,options_.graph_format);
                     if TeX && any(strcmp('eps',cellstr(options_.graph_format)))
                         fprintf(fidTeX,'\\begin{figure}[H]\n');
-                        for j = 1:m
-                            fprintf(fidTeX,'\\psfrag{%s}[1][][0.5][0]{$%s$}\n',deblank(mylist((nbplt-1)*nstar+j,:)),deblank(mylistTeX((nbplt-1)*nstar+j,:)));
-                        end
                         fprintf(fidTeX,'\\centering \n');
-                        fprintf(fidTeX,'\\includegraphics[width=%2.2f\\textwidth]{%s_IRF_%s%s}\n',options_.figures.textwidth*min(m/lc,1),[M_.fname, '/graphs/' M_.fname],tit{i},int2str(nbplt));
+                        fprintf(fidTeX,'\\includegraphics[width=%2.2f\\textwidth]{%s_IRF_%s%s}\n',options_.figures.textwidth*min(m/lc,1),[M_.dname, '/graphs/' M_.fname],tit{i},int2str(nbplt));
                         if options_.relative_irf
                             fprintf(fidTeX,'\\caption{Relative impulse response functions (orthogonalized shock to $%s$).}', titTeX{i});
                         else
