@@ -24,7 +24,7 @@ function [dr, info] = stochastic_solvers(dr, task, M_, options_, oo_)
 %                                 info=6 -> The jacobian matrix evaluated at the steady state is complex.
 %                                 info=9 -> k_order_pert was unable to compute the solution
 
-% Copyright (C) 1996-2019 Dynare Team
+% Copyright (C) 1996-2021 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -39,7 +39,7 @@ function [dr, info] = stochastic_solvers(dr, task, M_, options_, oo_)
 % GNU General Public License for more details.
 %
 % You should have received a copy of the GNU General Public License
-% along with Dynare.  If not, see <http://www.gnu.org/licenses/>.
+% along with Dynare.  If not, see <https://www.gnu.org/licenses/>.
 
 info = 0;
 
@@ -84,16 +84,11 @@ if M_.maximum_endo_lead==0 && M_.exo_det_nbr~=0
 end
 
 if options_.k_order_solver
-    if options_.risky_steadystate
-        [dr,info] = dyn_risky_steadystate_solver(oo_.steady_state,M_,dr, ...
-                                                 options_,oo_);
-    else
-        orig_order = options_.order;
-        options_.order = local_order;
-        dr = set_state_space(dr,M_,options_);
-        [dr,info] = k_order_pert(dr,M_,options_);
-        options_.order = orig_order;
-    end
+    orig_order = options_.order;
+    options_.order = local_order;
+    dr = set_state_space(dr,M_,options_);
+    [dr,info] = k_order_pert(dr,M_,options_);
+    options_.order = orig_order;
     return
 end
 
@@ -111,8 +106,8 @@ it_ = M_.maximum_lag + 1;
 z = repmat(dr.ys,1,klen);
 if local_order == 1
     if (options_.bytecode)
-        [chck, ~, loc_dr] = bytecode('dynamic','evaluate', z,exo_simul, ...
-                                     M_.params, dr.ys, 1);
+        [~, loc_dr] = bytecode('dynamic','evaluate', z,exo_simul, ...
+                               M_.params, dr.ys, 1);
         jacobia_ = [loc_dr.g1 loc_dr.g1_x loc_dr.g1_xd];
     else
         [~,jacobia_] = feval([M_.fname '.dynamic'],z(iyr0),exo_simul, ...
@@ -120,25 +115,20 @@ if local_order == 1
     end
 elseif local_order == 2
     if (options_.bytecode)
-        [chck, ~, loc_dr] = bytecode('dynamic','evaluate', z,exo_simul, ...
-                                     M_.params, dr.ys, 1);
+        [~, loc_dr] = bytecode('dynamic','evaluate', z,exo_simul, ...
+                               M_.params, dr.ys, 1);
         jacobia_ = [loc_dr.g1 loc_dr.g1_x];
     else
         [~,jacobia_,hessian1] = feval([M_.fname '.dynamic'],z(iyr0),...
                                       exo_simul, ...
                                       M_.params, dr.ys, it_);
     end
-    if options_.use_dll
-        % In USE_DLL mode, the hessian is in the 3-column sparse representation
-        hessian1 = sparse(hessian1(:,1), hessian1(:,2), hessian1(:,3), ...
-                          size(jacobia_, 1), size(jacobia_, 2)*size(jacobia_, 2));
-    end
     [infrow,infcol]=find(isinf(hessian1));
     if options_.debug
         if ~isempty(infrow)
             fprintf('\nSTOCHASTIC_SOLVER: The Hessian of the dynamic model contains Inf.\n')
             fprintf('STOCHASTIC_SOLVER: Try running model_diagnostics to find the source of the problem.\n')
-            save([M_.fname '_debug.mat'],'hessian1')
+            save([M_.dname filesep 'Output' filesep M_.fname '_debug.mat'],'hessian1')
         end
     end
     if ~isempty(infrow)
@@ -150,7 +140,7 @@ elseif local_order == 2
         if ~isempty(nanrow)
             fprintf('\nSTOCHASTIC_SOLVER: The Hessian of the dynamic model contains NaN.\n')
             fprintf('STOCHASTIC_SOLVER: Try running model_diagnostics to find the source of the problem.\n')
-            save([M_.fname '_debug.mat'],'hessian1')
+            save([M_.dname filesep 'Output' filesep M_.fname '_debug.mat'],'hessian1')
         end
     end
     if ~isempty(nanrow)
@@ -165,7 +155,7 @@ if options_.debug
     if ~isempty(infrow)
         fprintf('\nSTOCHASTIC_SOLVER: The Jacobian of the dynamic model contains Inf. The problem is associated with:\n\n')
         display_problematic_vars_Jacobian(infrow,infcol,M_,dr.ys,'dynamic','STOCHASTIC_SOLVER: ')
-        save([M_.fname '_debug.mat'],'jacobia_')
+        save([M_.dname filesep 'Output' filesep M_.fname '_debug.mat'],'jacobia_')
     end
 end
 
@@ -194,7 +184,7 @@ if options_.debug
     if ~isempty(nanrow)
         fprintf('\nSTOCHASTIC_SOLVER: The Jacobian of the dynamic model contains NaN. The problem is associated with:\n\n')
         display_problematic_vars_Jacobian(nanrow,nancol,M_,dr.ys,'dynamic','STOCHASTIC_SOLVER: ')
-        save([M_.fname '_debug.mat'],'jacobia_')
+        save([M_.dname filesep 'Output' filesep M_.fname '_debug.mat'],'jacobia_')
     end
 end
 
@@ -226,6 +216,11 @@ if M_.maximum_endo_lead == 0
     % backward models: simplified code exist only at order == 1
     if local_order == 1
         [k1,~,k2] = find(kstate(:,4));
+        if M_.maximum_endo_lag
+            dr.state_var = find(M_.lead_lag_incidence(1,:));
+        else
+            dr.state_var = [];
+        end
         dr.ghx(:,k1) = -b\jacobia_(:,k2);
         if M_.exo_nbr
             dr.ghu =  -b\jacobia_(:,nz+1:end);
@@ -247,12 +242,6 @@ if M_.maximum_endo_lead == 0
         error(['2nd and 3rd order approximation not implemented for purely ' ...
                'backward models'])
     end
-elseif options_.risky_steadystate
-    orig_order = options_.order;
-    options_.order = local_order;
-    [dr,info] = dyn_risky_steadystate_solver(oo_.steady_state,M_,dr, ...
-                                             options_,oo_);
-    options_.order = orig_order;
 else
     % If required, use AIM solver if not check only
     if options_.aim_solver && (task == 0)
