@@ -1,5 +1,5 @@
 /*
- * Copyright © 2009-2019 Dynare Team
+ * Copyright © 2009-2020 Dynare Team
  *
  * This file is part of Dynare.
  *
@@ -14,7 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with Dynare.  If not, see <http://www.gnu.org/licenses/>.
+ * along with Dynare.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifndef _DYNMEX_H
@@ -26,20 +26,6 @@
 
 #include <mex.h>
 
-/*
- * Fix for trac ticket Ticket #137
- */
-#if !defined(DYN_MEX_FUNC_ERR_MSG_TXT)
-# define DYN_MEX_FUNC_ERR_MSG_TXT(str)          \
-  do {                                          \
-    mexPrintf("%s\n", str);                     \
-    int i;                                      \
-    for (i = 0; i < nlhs; i++)                  \
-      plhs[i] = mxCreateDoubleScalar(1);        \
-    return;                                     \
-  } while (0)
-#endif
-
 #if defined(MATLAB_MEX_FILE) && MATLAB_VERSION < 0x0805
 # define mxIsScalar(x) (mxGetM(x) == 1 && mxGetN(x) == 1)
 #endif
