@@ -1,5 +1,5 @@
 /*
- * Copyright © 2010-2019 Dynare Team
+ * Copyright © 2010-2021 Dynare Team
  *
  * This file is part of Dynare.
  *
@@ -14,7 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with Dynare.  If not, see <http://www.gnu.org/licenses/>.
+ * along with Dynare.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include <iostream>
@@ -56,8 +56,8 @@ Path::Path(vector<string> includepath_arg)
 
 SlaveNode::SlaveNode(string computerName_arg, string port_arg, int minCpuNbr_arg, int maxCpuNbr_arg, string userName_arg,
                      string password_arg, string remoteDrive_arg, string remoteDirectory_arg,
-                     string dynarePath_arg, string matlabOctavePath_arg, bool singleCompThread_arg, int numberOfThreadsPerJob_arg,
-                     string operatingSystem_arg) :
+                     string programPath_arg, string programConfig_arg, string matlabOctavePath_arg, bool singleCompThread_arg,
+                     int numberOfThreadsPerJob_arg, string operatingSystem_arg) :
   computerName{move(computerName_arg)},
   port{move(port_arg)},
   minCpuNbr{minCpuNbr_arg},
@@ -66,7 +66,8 @@ SlaveNode::SlaveNode(string computerName_arg, string port_arg, int minCpuNbr_arg
   password{move(password_arg)},
   remoteDrive{move(remoteDrive_arg)},
   remoteDirectory{move(remoteDirectory_arg)},
-  dynarePath{move(dynarePath_arg)},
+  programPath{move(programPath_arg)},
+  programConfig{move(programConfig_arg)},
   matlabOctavePath{move(matlabOctavePath_arg)},
   singleCompThread{singleCompThread_arg},
   numberOfThreadsPerJob{numberOfThreadsPerJob_arg},
@@ -97,9 +98,12 @@ Cluster::Cluster(member_nodes_t member_nodes_arg) :
 }
 
 ConfigFile::ConfigFile(bool parallel_arg, bool parallel_test_arg,
-                       bool parallel_slave_open_mode_arg, string cluster_name_arg) :
+                       bool parallel_slave_open_mode_arg, bool parallel_use_psexec_arg,
+                       string cluster_name_arg) :
   parallel{parallel_arg}, parallel_test{parallel_test_arg},
-  parallel_slave_open_mode{parallel_slave_open_mode_arg}, cluster_name{move(cluster_name_arg)}
+  parallel_slave_open_mode{parallel_slave_open_mode_arg},
+  parallel_use_psexec{parallel_use_psexec_arg},
+  cluster_name{move(cluster_name_arg)}
 {
 }
 
@@ -168,8 +172,8 @@ ConfigFile::getConfigFileInfo(const string &config_file)
     }
 
   string name, computerName, port, userName, password, remoteDrive,
-    remoteDirectory, dynarePath, matlabOctavePath, operatingSystem,
-    global_init_file;
+    remoteDirectory, programPath, programConfig, matlabOctavePath,
+    operatingSystem, global_init_file;
   vector<string> includepath;
   int minCpuNbr{0}, maxCpuNbr{0};
   int numberOfThreadsPerJob{1};
@@ -202,8 +206,8 @@ ConfigFile::getConfigFileInfo(const string &config_file)
             addParallelConfFileElement(inNode, inCluster, member_nodes, name,
                                        computerName, port, minCpuNbr, maxCpuNbr, userName,
                                        password, remoteDrive, remoteDirectory,
-                                       dynarePath, matlabOctavePath, singleCompThread, numberOfThreadsPerJob,
-                                       operatingSystem);
+                                       programPath, programConfig, matlabOctavePath, singleCompThread,
+                                       numberOfThreadsPerJob, operatingSystem);
 
           //! Reset communication vars / option defaults
           if (!line.compare("[hooks]"))
@@ -236,7 +240,7 @@ ConfigFile::getConfigFileInfo(const string &config_file)
             }
 
           name = userName = computerName = port = password = remoteDrive
-            = remoteDirectory = dynarePath = matlabOctavePath
+            = remoteDirectory = programPath = programConfig = matlabOctavePath
             = operatingSystem = global_init_file = "";
           includepath.clear();
           minCpuNbr = maxCpuNbr = 0;
@@ -353,8 +357,11 @@ ConfigFile::getConfigFileInfo(const string &config_file)
               remoteDrive = tokenizedLine.back();
             else if (!tokenizedLine.front().compare("RemoteDirectory"))
               remoteDirectory = tokenizedLine.back();
-            else if (!tokenizedLine.front().compare("DynarePath"))
-              dynarePath = tokenizedLine.back();
+            else if (!tokenizedLine.front().compare("DynarePath")
+                     || !tokenizedLine.front().compare("ProgramPath"))
+              programPath = tokenizedLine.back();
+            else if (!tokenizedLine.front().compare("ProgramConfig"))
+              programConfig = tokenizedLine.back();
             else if (!tokenizedLine.front().compare("MatlabOctavePath"))
               matlabOctavePath = tokenizedLine.back();
             else if (!tokenizedLine.front().compare("NumberOfThreadsPerJob"))
@@ -445,8 +452,8 @@ ConfigFile::getConfigFileInfo(const string &config_file)
     addParallelConfFileElement(inNode, inCluster, member_nodes, name,
                                computerName, port, minCpuNbr, maxCpuNbr, userName,
                                password, remoteDrive, remoteDirectory,
-                               dynarePath, matlabOctavePath, singleCompThread, numberOfThreadsPerJob,
-                               operatingSystem);
+                               programPath, programConfig, matlabOctavePath, singleCompThread,
+                               numberOfThreadsPerJob, operatingSystem);
 
   configFile.close();
 }
@@ -477,9 +484,10 @@ ConfigFile::addPathsConfFileElement(vector<string> includepath)
 
 void
 ConfigFile::addParallelConfFileElement(bool inNode, bool inCluster, const member_nodes_t &member_nodes, const string &name,
-                                       const string &computerName, const string &port, int minCpuNbr, int maxCpuNbr, const string &userName,
-                                       const string &password, const string &remoteDrive, const string &remoteDirectory,
-                                       const string &dynarePath, const string &matlabOctavePath, bool singleCompThread, int numberOfThreadsPerJob,
+                                       const string &computerName, const string &port, int minCpuNbr, int maxCpuNbr,
+                                       const string &userName, const string &password, const string &remoteDrive,
+                                       const string &remoteDirectory, const string &programPath, const string &programConfig,
+                                       const string &matlabOctavePath, bool singleCompThread, int numberOfThreadsPerJob,
                                        const string &operatingSystem)
 {
   //! ADD NODE
@@ -497,14 +505,15 @@ ConfigFile::addParallelConfFileElement(bool inNode, bool inCluster, const member
         }
       else
         slave_nodes.emplace(name, SlaveNode{computerName, port, minCpuNbr, maxCpuNbr, userName,
-                                              password, remoteDrive, remoteDirectory, dynarePath,
+                                              password, remoteDrive, remoteDirectory, programPath, programConfig,
                                               matlabOctavePath, singleCompThread, numberOfThreadsPerJob,
                                               operatingSystem});
   //! ADD CLUSTER
   else if (inCluster)
     if (minCpuNbr > 0 || maxCpuNbr > 0 || !userName.empty()
         || !password.empty() || !remoteDrive.empty() || !remoteDirectory.empty()
-        || !dynarePath.empty() || !matlabOctavePath.empty() || !operatingSystem.empty())
+        || !programPath.empty() || !programConfig.empty()
+        || !matlabOctavePath.empty() || !operatingSystem.empty())
       {
         cerr << "Invalid option passed to [cluster]." << endl;
         exit(EXIT_FAILURE);
@@ -728,7 +737,9 @@ ConfigFile::writeCluster(ostream &output) const
              << "'Password', '" << slave_node.second.password << "', "
              << "'RemoteDrive', '" << slave_node.second.remoteDrive << "', "
              << "'RemoteDirectory', '" << slave_node.second.remoteDirectory << "', "
-             << "'DynarePath', '" << slave_node.second.dynarePath << "', "
+        // The following should be switched back to “ProgramPath” once we move to Dragonfly
+             << "'DynarePath', '" << slave_node.second.programPath << "', "
+             << "'ProgramConfig', '" << slave_node.second.programConfig << "', "
              << "'MatlabOctavePath', '" << slave_node.second.matlabOctavePath << "', "
              << "'OperatingSystem', '" << slave_node.second.operatingSystem << "', "
              << "'NodeWeight', '" << (cluster_it->second.member_nodes.find(slave_node.first))->second << "', "
@@ -740,8 +751,13 @@ ConfigFile::writeCluster(ostream &output) const
         output << "'SingleCompThread', 'false');" << endl;
     }
 
+  // Default values for the following two are both in DynareMain.cc and matlab/default_option_values.m
   if (parallel_slave_open_mode)
     output << "options_.parallel_info.leaveSlaveOpen = 1;" << endl;
+  if (!parallel_use_psexec)
+    output << "options_.parallel_use_psexec = false;" << endl;
+
+  output << "options_.parallel_info.console_mode= isoctave;" << endl;
 
   output << "InitializeComputationalEnvironment();" << endl;
   if (parallel_test)
