@@ -124,6 +124,9 @@ ModelTree::ModelTree(SymbolTable &symbol_table_arg,
   NNZDerivatives(4, 0),
   temporary_terms_derivatives(4)
 {
+  // Ensure that elements accessed by {Static,Dynamic}Model:write{Json,}ParamsDerivativesFile() exist
+  for (const auto &ord : {pair{0, 1}, pair{1, 1}, pair{0, 2}, pair{1, 2}, pair{2, 1}, pair{3, 1}})
+    params_derivatives.emplace(ord, decltype(params_derivatives)::mapped_type{});
 }
 
 ModelTree::ModelTree(const ModelTree &m) :
@@ -996,7 +999,7 @@ ModelTree::computeTemporaryTerms(bool is_matlab, bool no_tmp_terms)
 }
 
 void
-ModelTree::computeBlockTemporaryTerms()
+ModelTree::computeBlockTemporaryTerms(bool no_tmp_terms)
 {
   int nb_blocks = blocks.size();
   blocks_temporary_terms.resize(nb_blocks);
@@ -1007,7 +1010,16 @@ ModelTree::computeBlockTemporaryTerms()
       blocks_temporary_terms[blk].resize(blocks[blk].size + 1);
       for (int eq = 0; eq < blocks[blk].size; eq++)
         {
-          if (eq < blocks[blk].getRecursiveSize() && isBlockEquationRenormalized(blk, eq))
+          /* It is important to compute temporary terms of the renormalized
+             equation if the latter is going to be used in the output files.
+             Otherwise, for an equation of the form log(x) = RHS, a temporary
+             term could be associated to log(x), and since it would be
+             associated to this equation, it would be printed and thus computed
+             *before* x is actually evaluated, and thus would be incorrect. */
+          if ((blocks[blk].simulation_type == BlockSimulationType::evaluateBackward
+               || blocks[blk].simulation_type == BlockSimulationType::evaluateForward
+               || eq < blocks[blk].getRecursiveSize())
+              && isBlockEquationRenormalized(blk, eq))
             getBlockEquationRenormalizedExpr(blk, eq)->computeBlockTemporaryTerms(blk, eq, blocks_temporary_terms, reference_count);
           else
             getBlockEquationExpr(blk, eq)->computeBlockTemporaryTerms(blk, eq, blocks_temporary_terms, reference_count);
@@ -1018,6 +1030,18 @@ ModelTree::computeBlockTemporaryTerms()
       additionalBlockTemporaryTerms(blk, blocks_temporary_terms, reference_count);
     }
 
+  /* If the user has specified the notmpterms option, clear all temporary
+     terms, except those that correspond to external functions (since they are
+     not optional) */
+  if (no_tmp_terms)
+    for (auto &it : blocks_temporary_terms)
+      for (auto &it2 : it)
+        for (auto it3 = it2.begin(); it3 != it2.end();)
+          if (!dynamic_cast<AbstractExternalFunctionNode *>(*it3))
+            it3 = it2.erase(it3);
+          else
+            ++it3;
+
   // Compute indices in the temporary terms vector
   int idx = 0;
   blocks_temporary_terms_idxs.clear();
@@ -1890,8 +1914,8 @@ ModelTree::matlab_arch(const string &mexext)
 string
 ModelTree::findGccOnMacos()
 {
-  const string macos_gcc_version{"11"}; // doc/manual/source/installation-and-configuration.rst
-                                        // should be updated when this is changed
+  const string macos_gcc_version {"12"}; // doc/manual/source/installation-and-configuration.rst
+                                         // should be updated when this is changed
   char dynare_preprocessor_path[PATH_MAX];
   uint32_t size = PATH_MAX;
   string local_gcc_path;
