@@ -1,5 +1,5 @@
 /*
- * Copyright © 2003-2020 Dynare Team
+ * Copyright © 2003-2021 Dynare Team
  *
  * This file is part of Dynare.
  *
@@ -14,7 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with Dynare.  If not, see <http://www.gnu.org/licenses/>.
+ * along with Dynare.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include <iostream>
@@ -56,15 +56,6 @@ InitParamStatement::writeOutput(ostream &output, const string &basename, bool mi
     output << symbol_table.getName(symb_id) << " = M_.params(" << id << ");" << endl;
 }
 
-void
-InitParamStatement::writeJuliaOutput(ostream &output, const string &basename)
-{
-  int id = symbol_table.getTypeSpecificID(symb_id) + 1;
-  output << "model_.params[ " << id << " ] = ";
-  param_value->writeOutput(output);
-  output << endl;
-}
-
 void
 InitParamStatement::writeJsonOutput(ostream &output) const
 {
@@ -98,11 +89,11 @@ InitOrEndValStatement::InitOrEndValStatement(init_values_t init_values_arg,
 void
 InitOrEndValStatement::fillEvalContext(eval_context_t &eval_context) const
 {
-  for (const auto &init_value : init_values)
+  for (auto [symb_id, value] : init_values)
     {
       try
         {
-          eval_context[init_value.first] = (init_value.second)->eval(eval_context);
+          eval_context[symb_id] = value->eval(eval_context);
         }
       catch (ExprNode::EvalException &e)
         {
@@ -128,8 +119,8 @@ InitOrEndValStatement::getUninitializedVariables(SymbolType type)
       exit(EXIT_FAILURE);
     }
 
-  for (const auto &init_value : init_values)
-    if (auto sit = unused.find(init_value.first);
+  for (auto [symb_id, value] : init_values)
+    if (auto sit = unused.find(symb_id);
         sit != unused.end())
       unused.erase(sit);
 
@@ -139,10 +130,10 @@ InitOrEndValStatement::getUninitializedVariables(SymbolType type)
 void
 InitOrEndValStatement::writeInitValues(ostream &output) const
 {
-  for (const auto &init_value : init_values)
+  for (auto [symb_id, value] : init_values)
     {
-      const int symb_id = init_value.first;
-      const expr_t expression = init_value.second;
+      if (symbol_table.getType(symb_id) == SymbolType::unusedEndogenous) // See #82
+        continue;
 
       SymbolType type = symbol_table.getType(symb_id);
       int tsid = symbol_table.getTypeSpecificID(symb_id) + 1;
@@ -168,7 +159,7 @@ InitOrEndValStatement::writeInitValues(ostream &output) const
         }
 
       output << "(" << tsid << ") = ";
-      expression->writeOutput(output);
+      value->writeOutput(output);
       output << ";" << endl;
     }
 }
@@ -177,12 +168,15 @@ void
 InitOrEndValStatement::writeJsonInitValues(ostream &output) const
 {
   for (auto it = init_values.begin();
-       it != init_values.end(); it++)
+       it != init_values.end(); ++it)
     {
+      auto [symb_id, value] = *it;
+      if (symbol_table.getType(symb_id) == SymbolType::unusedEndogenous) // See #82
+        continue;
       if (it != init_values.begin())
         output << ", ";
-      output << R"({"name": ")" << symbol_table.getName(it->first) << R"(", )" << R"("value": ")";
-      it->second->writeJsonOutput(output, {}, {});
+      output << R"({"name": ")" << symbol_table.getName(symb_id) << R"(", )" << R"("value": ")";
+      value->writeJsonOutput(output, {}, {});
       output << R"("})";
     }
 }
@@ -322,13 +316,14 @@ HistValStatement::checkPass(ModFileStructure &mod_file_struct, WarningConsolidat
       set<int> unused_endo = symbol_table.getEndogenous();
       set<int> unused_exo = symbol_table.getExogenous();
 
-      for (const auto &hist_value : hist_values)
+      for (const auto &[key, value] : hist_values)
         {
-          if (auto sit = unused_endo.find(hist_value.first.first);
+          int symb_id = key.first;
+          if (auto sit = unused_endo.find(symb_id);
               sit != unused_endo.end())
             unused_endo.erase(sit);
 
-          if (auto sit = unused_exo.find(hist_value.first.first);
+          if (auto sit = unused_exo.find(symb_id);
               sit != unused_exo.end())
             unused_exo.erase(sit);
         }
@@ -370,14 +365,14 @@ HistValStatement::writeOutput(ostream &output, const string &basename, bool mini
          << (symbol_table.exo_det_nbr() > 0 ? "M_.exo_det_names; " : "")
          << "]);" << endl;
 
-  for (const auto &hist_value : hist_values)
+  for (const auto &[key, value] : hist_values)
     {
-      int symb_id = hist_value.first.first;
-      int lag = hist_value.first.second;
-      const expr_t expression = hist_value.second;
+      auto [symb_id, lag] = key;
+      if (symbol_table.getType(symb_id) == SymbolType::unusedEndogenous) // See #82
+        continue;
 
       output << "M_.histval_dseries{'" << symbol_table.getName(symb_id) << "'}(dates('" << lag << "Y'))=";
-      expression->writeOutput(output);
+      value->writeOutput(output);
       output << ";" << endl;
     }
 
@@ -400,10 +395,13 @@ HistValStatement::writeJsonOutput(ostream &output) const
   for (auto it = hist_values.begin();
        it != hist_values.end(); ++it)
     {
+      auto [symb_id, lag] = it->first;
+      if (symbol_table.getType(symb_id) == SymbolType::unusedEndogenous) // See #82
+        continue;
       if (it != hist_values.begin())
         output << ", ";
-      output << R"({ "name": ")" << symbol_table.getName(it->first.first) << R"(")"
-             << R"(, "lag": )" << it->first.second
+      output << R"({ "name": ")" << symbol_table.getName(symb_id) << R"(")"
+             << R"(, "lag": )" << lag
              << R"(, "value": ")";
       it->second->writeJsonOutput(output, {}, {});
       output << R"("})";
@@ -411,8 +409,8 @@ HistValStatement::writeJsonOutput(ostream &output) const
   output << "]}";
 }
 
-InitvalFileStatement::InitvalFileStatement(string filename_arg) :
-  filename{move(filename_arg)}
+InitvalFileStatement::InitvalFileStatement(OptionsList options_list_arg) :
+  options_list{move(options_list_arg)}
 {
 }
 
@@ -422,35 +420,49 @@ InitvalFileStatement::writeOutput(ostream &output, const string &basename, bool
   output << "%" << endl
          << "% INITVAL_FILE statement" << endl
          << "%" << endl
-         << "options_.initval_file = true;" << endl
-         << "initvalf('" << filename << "');" << endl;
+         << "options_.initval_file = true;" << endl;
+  options_list.writeOutput(output, "options_initvalf");
+  output << "oo_.initval_series = initvalf(M_, options_initvalf);" << endl;
 }
 
 void
 InitvalFileStatement::writeJsonOutput(ostream &output) const
 {
-  output << R"({"statementName": "init_val_file")"
-         << R"(, "filename": ")" << filename << R"(")"
-         << "}";
+  output << R"({"statementName": "initval_file")";
+  if (options_list.getNumberOfOptions())
+    {
+      output << ", ";
+      options_list.writeJsonOutput(output);
+    }
+  output << "}";
 }
 
-HistvalFileStatement::HistvalFileStatement(string filename_arg) :
-  filename{move(filename_arg)}
+HistvalFileStatement::HistvalFileStatement(OptionsList options_list_arg) :
+  options_list{move(options_list_arg)}
 {
 }
 
 void
 HistvalFileStatement::writeOutput(ostream &output, const string &basename, bool minimal_workspace) const
 {
-  output << "histvalf('" << filename << "');" << endl;
+  output << "%" << endl
+         << "% HISTVAL_FILE statement" << endl
+         << "%" << endl
+         << "options_.histval_file = true;" << endl;
+  options_list.writeOutput(output, "options_histvalf");
+  output << "[M_.endo_histval, M_.exo_histval, M_.exo_det_histval] = histvalf(M_, options_histvalf);" << endl;
 }
 
 void
 HistvalFileStatement::writeJsonOutput(ostream &output) const
 {
-  output << R"({"statementName": "hist_val_file")"
-         << R"(, "filename": ")" << filename << R"(")"
-         << "}";
+  output << R"({"statementName": "histval_file")";
+  if (options_list.getNumberOfOptions())
+    {
+      output << ", ";
+      options_list.writeJsonOutput(output);
+    }
+  output << "}";
 }
 
 HomotopyStatement::HomotopyStatement(homotopy_values_t homotopy_values_arg,
@@ -597,7 +609,7 @@ LoadParamsAndSteadyStateStatement::writeOutput(ostream &output, const string &ba
 void
 LoadParamsAndSteadyStateStatement::writeJsonOutput(ostream &output) const
 {
-  output << R"({"statementName": "load_params_and_steady_state")"
+  output << R"({"statementName": "load_params_and_steady_state",)"
          << R"("values": [)";
   for (auto it = content.begin(); it != content.end(); ++it)
     {
