@@ -1,5 +1,5 @@
 /*
- * Copyright © 2003-2019 Dynare Team
+ * Copyright © 2003-2021 Dynare Team
  *
  * This file is part of Dynare.
  *
@@ -14,7 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with Dynare.  If not, see <http://www.gnu.org/licenses/>.
+ * along with Dynare.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include <cassert>
@@ -44,12 +44,8 @@ AbstractShocksStatement::writeDetShocks(ostream &output) const
     {
       bool exo_det = (symbol_table.getType(id) == SymbolType::exogenousDet);
 
-      for (const auto &it : shock_vec)
+      for (const auto &[period1, period2, value] : shock_vec)
         {
-          int period1 = it.period1;
-          int period2 = it.period2;
-          expr_t value = it.value;
-
           output << "M_.det_shocks = [ M_.det_shocks;" << endl
                  << "struct('exo_det'," << static_cast<int>(exo_det)
                  << ",'exo_id'," << symbol_table.getTypeSpecificID(id)+1
@@ -78,12 +74,13 @@ AbstractShocksStatement::writeJsonDetShocks(ostream &output) const
              << R"("values": [)";
       for (auto it1 = it->second.begin(); it1 != it->second.end(); ++it1)
         {
+          auto [period1, period2, value] = *it1;
           if (it1 != it->second.begin())
             output << ", ";
-          output << R"({"period1": )" << it1->period1 << ", "
-                 << R"("period2": )" << it1->period2 << ", "
+          output << R"({"period1": )" << period1 << ", "
+                 << R"("period2": )" << period2 << ", "
                  << R"("value": ")";
-          it1->value->writeJsonOutput(output, {}, {});
+          value->writeJsonOutput(output, {}, {});
           output << R"("})";
         }
       output << "]}";
@@ -92,13 +89,13 @@ AbstractShocksStatement::writeJsonDetShocks(ostream &output) const
 }
 
 ShocksStatement::ShocksStatement(bool overwrite_arg,
-                                 const det_shocks_t &det_shocks_arg,
+                                 det_shocks_t det_shocks_arg,
                                  var_and_std_shocks_t var_shocks_arg,
                                  var_and_std_shocks_t std_shocks_arg,
                                  covar_and_corr_shocks_t covar_shocks_arg,
                                  covar_and_corr_shocks_t corr_shocks_arg,
                                  const SymbolTable &symbol_table_arg) :
-  AbstractShocksStatement{false, overwrite_arg, det_shocks_arg, symbol_table_arg},
+  AbstractShocksStatement{false, overwrite_arg, move(det_shocks_arg), symbol_table_arg},
   var_shocks{move(var_shocks_arg)},
   std_shocks{move(std_shocks_arg)},
   covar_shocks{move(covar_shocks_arg)},
@@ -151,11 +148,7 @@ void
 ShocksStatement::writeJsonOutput(ostream &output) const
 {
   output << R"({"statementName": "shocks")"
-         << R"(, "overwrite": )";
-  if (overwrite)
-    output << "true";
-  else
-    output << "false";
+         << R"(, "overwrite": )" << (overwrite ? "true" : "false");
   if (!det_shocks.empty())
     {
       output << ", ";
@@ -403,9 +396,9 @@ ShocksStatement::has_calibrated_measurement_errors() const
 }
 
 MShocksStatement::MShocksStatement(bool overwrite_arg,
-                                   const det_shocks_t &det_shocks_arg,
+                                   det_shocks_t det_shocks_arg,
                                    const SymbolTable &symbol_table_arg) :
-  AbstractShocksStatement{true, overwrite_arg, det_shocks_arg, symbol_table_arg}
+  AbstractShocksStatement{true, overwrite_arg, move(det_shocks_arg), symbol_table_arg}
 {
 }
 
@@ -422,6 +415,82 @@ MShocksStatement::writeOutput(ostream &output, const string &basename, bool mini
   writeDetShocks(output);
 }
 
+void
+MShocksStatement::writeJsonOutput(ostream &output) const
+{
+  output << R"({"statementName": "mshocks")"
+         << R"(, "overwrite": )" << (overwrite ? "true" : "false");
+  if (!det_shocks.empty())
+    {
+      output << ", ";
+      writeJsonDetShocks(output);
+    }
+  output << "}";
+}
+
+ShocksSurpriseStatement::ShocksSurpriseStatement(bool overwrite_arg,
+                                                 AbstractShocksStatement::det_shocks_t surprise_shocks_arg,
+                                                 const SymbolTable &symbol_table_arg) :
+  overwrite{overwrite_arg}, surprise_shocks{move(surprise_shocks_arg)},
+  symbol_table{symbol_table_arg}
+{
+}
+
+void
+ShocksSurpriseStatement::checkPass(ModFileStructure &mod_file_struct, WarningConsolidation &warnings)
+{
+  mod_file_struct.shocks_surprise_present = true;
+}
+
+void
+ShocksSurpriseStatement::writeOutput(ostream &output, const string &basename, bool minimal_workspace) const
+{
+  if (overwrite)
+    output << "M_.surprise_shocks = [" << endl;
+  else
+    output << "M_.surprise_shocks = [ M_.surprise_shocks;" << endl;
+  for (const auto &[id, shock_vec] : surprise_shocks)
+    {
+      for (const auto &[period1, period2, value] : shock_vec)
+        {
+          output << "struct('exo_id'," << symbol_table.getTypeSpecificID(id)+1
+                 << ",'periods'," << period1 << ":" << period2
+                 << ",'value',";
+          value->writeOutput(output);
+          output << ");" << endl;
+        }
+    }
+  output << "];" << endl;
+}
+
+void
+ShocksSurpriseStatement::writeJsonOutput(ostream &output) const
+{
+  output << R"({"statementName": "shocks")"
+         << R"(, "surprise": true)"
+         << R"(, "surprise_shocks": [)";
+  for (auto it = surprise_shocks.begin(); it != surprise_shocks.end(); ++it)
+    {
+      if (it != surprise_shocks.begin())
+        output << ", ";
+      output << R"({"var": ")" << symbol_table.getName(it->first) << R"(", )"
+             << R"("values": [)";
+      for (auto it1 = it->second.begin(); it1 != it->second.end(); ++it1)
+        {
+          auto [period1, period2, value] = *it1;
+          if (it1 != it->second.begin())
+            output << ", ";
+          output << R"({"period1": )" << period1 << ", "
+                 << R"("period2": )" << period2 << ", "
+                 << R"("value": ")";
+          value->writeJsonOutput(output, {}, {});
+          output << R"("})";
+        }
+      output << "]}";
+    }
+  output << "]}";
+}
+
 ConditionalForecastPathsStatement::ConditionalForecastPathsStatement(AbstractShocksStatement::det_shocks_t paths_arg,
                                                                      const SymbolTable &symbol_table_arg) :
   paths{move(paths_arg)},
@@ -432,13 +501,12 @@ ConditionalForecastPathsStatement::ConditionalForecastPathsStatement(AbstractSho
 void
 ConditionalForecastPathsStatement::checkPass(ModFileStructure &mod_file_struct, WarningConsolidation &warnings)
 {
-  for (const auto &path : paths)
+  for (const auto &[ignore, elems] : paths)
     {
       int this_path_length = 0;
-      const vector<AbstractShocksStatement::DetShockElement> &elems = path.second;
-      for (auto elem : elems)
+      for (auto [period1, period2, value] : elems)
         // Period1 < Period2, as enforced in ParsingDriver::add_period()
-        this_path_length = max(this_path_length, elem.period2);
+        this_path_length = max(this_path_length, period2);
       path_length = max(this_path_length, path_length);
     }
 }
@@ -457,11 +525,11 @@ ConditionalForecastPathsStatement::writeOutput(ostream &output, const string &ba
         output << "constrained_vars_ = " << symbol_table.getTypeSpecificID(it->first) + 1 << ";" << endl;
       else
         output << "constrained_vars_ = [constrained_vars_; " << symbol_table.getTypeSpecificID(it->first) + 1 << "];" << endl;
-      for (const auto &elem : it->second)
-        for (int j = elem.period1; j <= elem.period2; j++)
+      for (const auto &[period1, period2, value] : it->second)
+        for (int j = period1; j <= period2; j++)
           {
             output << "constrained_paths_(" << k << "," << j << ")=";
-            elem.value->writeOutput(output);
+            value->writeOutput(output);
             output << ";" << endl;
           }
     }
@@ -480,12 +548,13 @@ ConditionalForecastPathsStatement::writeJsonOutput(ostream &output) const
              << R"("values": [)";
       for (auto it1 = it->second.begin(); it1 != it->second.end(); ++it1)
         {
+          auto [period1, period2, value] = *it1;
           if (it1 != it->second.begin())
             output << ", ";
-          output << R"({"period1": )" << it1->period1 << ", "
-                 << R"("period2": )" << it1->period2 << ", "
+          output << R"({"period1": )" << period1 << ", "
+                 << R"("period2": )" << period2 << ", "
                  << R"("value": ")";
-          it1->value->writeJsonOutput(output, {}, {});
+          value->writeJsonOutput(output, {}, {});
           output << R"("})";
         }
       output << "]}";
@@ -712,3 +781,93 @@ Init2shocksStatement::writeJsonOutput(ostream &output) const
     }
   output << "]}";
 }
+
+HeteroskedasticShocksStatement::HeteroskedasticShocksStatement(bool overwrite_arg,
+                                                               const heteroskedastic_shocks_t &values_arg,
+                                                               const heteroskedastic_shocks_t &scales_arg,
+                                                               const SymbolTable &symbol_table_arg)
+  : overwrite{overwrite_arg}, values{values_arg}, scales{scales_arg}, symbol_table{symbol_table_arg}
+{
+}
+
+void
+HeteroskedasticShocksStatement::writeOutput(ostream &output, const string &basename, bool minimal_workspace) const
+{
+  // NB: The first initialization of the fields is done in ModFile::writeMOutput()
+  if (overwrite)
+    output << "M_.heteroskedastic_shocks.Qvalue_orig = [];" << endl
+           << "M_.heteroskedastic_shocks.Qscale_orig = [];" << endl;
+
+  for (const auto &[symb_id, vec] : values)
+    {
+      int tsid = symbol_table.getTypeSpecificID(symb_id);
+      for (const auto &[period1, period2, value] : vec)
+        {
+          output << "M_.heteroskedastic_shocks.Qvalue_orig = [M_.heteroskedastic_shocks.Qvalue_orig; struct('exo_id', "
+                 << tsid+1 << ",'periods',"
+                 << period1 << ":" << period2 << ",'value',";
+          value->writeOutput(output);
+          output << ")];" << endl;
+        }
+    }
+  for (const auto &[symb_id, vec] : scales)
+    {
+      int tsid = symbol_table.getTypeSpecificID(symb_id);
+      for (const auto &[period1, period2, scale] : vec)
+        {
+          output << "M_.heteroskedastic_shocks.Qscale_orig = [M_.heteroskedastic_shocks.Qscale_orig; struct('exo_id', "
+                 << tsid+1 << ",'periods',"
+                 << period1 << ":" << period2 << ",'scale',";
+          scale->writeOutput(output);
+          output << ")];" << endl;
+        }
+    }
+}
+
+void
+HeteroskedasticShocksStatement::writeJsonOutput(ostream &output) const
+{
+  output << R"({"statementName": "heteroskedastic_shocks")"
+         << R"(, "overwrite": )" << (overwrite ? "true" : "false")
+         << R"(, "shocks_values": [)";
+  for (auto it = values.begin(); it != values.end(); ++it)
+    {
+      if (it != values.begin())
+        output << ", ";
+      output << R"({"var": ")" << symbol_table.getName(it->first) << R"(", )"
+             << R"("values": [)";
+      for (auto it1 = it->second.begin(); it1 != it->second.end(); ++it1)
+        {
+          if (it1 != it->second.begin())
+            output << ", ";
+          auto [period1, period2, value] = *it1;
+          output << R"({"period1": )" << period1 << ", "
+                 << R"("period2": )" << period2 << ", "
+                 << R"("value": ")";
+          value->writeJsonOutput(output, {}, {});
+          output << R"("})";
+        }
+      output << "]}";
+    }
+  output << R"(], "shocks_scales": [)";
+  for (auto it = scales.begin(); it != scales.end(); ++it)
+    {
+      if (it != scales.begin())
+        output << ", ";
+      output << R"({"var": ")" << symbol_table.getName(it->first) << R"(", )"
+             << R"("scales": [)";
+      for (auto it1 = it->second.begin(); it1 != it->second.end(); ++it1)
+        {
+          if (it1 != it->second.begin())
+            output << ", ";
+          auto [period1, period2, value] = *it1;
+          output << R"({"period1": )" << period1 << ", "
+                 << R"("period2": )" << period2 << ", "
+                 << R"("value": ")";
+          value->writeJsonOutput(output, {}, {});
+          output << R"("})";
+        }
+      output << "]}";
+    }
+  output << "]}";
+}
