@@ -310,7 +310,7 @@ OptionsList::writeJsonOutput(ostream &output) const
   for (auto it = paired_num_options.begin();
        it != paired_num_options.end();)
     {
-      output << R"(")"<< it->first << R"(": [)" << it->second.first << " " << it->second.second << "]";
+      output << R"(")"<< it->first << R"(": [)" << it->second.first << ", " << it->second.second << "]";
       ++it;
       if (it != paired_num_options.end()
           || !(string_options.empty()
@@ -374,9 +374,7 @@ OptionsList::writeJsonOutput(ostream &output) const
             {
               output << *viit;
               ++viit;
-              if (viit != it->second.end()
-                  || !(vector_str_options.empty()
-                       && vector_cellstr_options.empty()))
+              if (viit != it->second.end())
                 output << ", ";
             }
         }
@@ -401,8 +399,7 @@ OptionsList::writeJsonOutput(ostream &output) const
             {
               output << R"(")" << *viit << R"(")";
               ++viit;
-              if (viit != it->second.end()
-                  || !(vector_cellstr_options.empty()))
+              if (viit != it->second.end())
                 output << ", ";
             }
         }
