@@ -1,5 +1,5 @@
 /*
- * Copyright © 2018-2019 Dynare Team
+ * Copyright © 2018-2021 Dynare Team
  *
  * This file is part of Dynare.
  *
@@ -14,7 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with Dynare.  If not, see <http://www.gnu.org/licenses/>.
+ * along with Dynare.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include <algorithm>
@@ -118,13 +118,13 @@ TrendComponentModelTable::setA0(map<string, map<tuple<int, int, int>, expr_t>> A
   A0star = move(A0star_arg);
 }
 
-map<string, vector<string>>
+const map<string, vector<string>> &
 TrendComponentModelTable::getEqTags() const
 {
   return eqtags;
 }
 
-vector<string>
+const vector<string> &
 TrendComponentModelTable::getEqTags(const string &name_arg) const
 {
   checkModelName(name_arg);
@@ -142,80 +142,80 @@ TrendComponentModelTable::checkModelName(const string &name_arg) const
     }
 }
 
-vector<int>
+const vector<int> &
 TrendComponentModelTable::getNonTargetLhs(const string &name_arg) const
 {
   checkModelName(name_arg);
   return nontarget_lhs.find(name_arg)->second;
 }
 
-vector<int>
+const vector<int> &
 TrendComponentModelTable::getTargetLhs(const string &name_arg) const
 {
   checkModelName(name_arg);
   return target_lhs.find(name_arg)->second;
 }
 
-vector<int>
+const vector<int> &
 TrendComponentModelTable::getLhs(const string &name_arg) const
 {
   checkModelName(name_arg);
   return lhs.find(name_arg)->second;
 }
 
-vector<expr_t>
+const vector<expr_t> &
 TrendComponentModelTable::getLhsExprT(const string &name_arg) const
 {
   checkModelName(name_arg);
   return lhs_expr_t.find(name_arg)->second;
 }
 
-map<string, vector<string>>
+const map<string, vector<string>> &
 TrendComponentModelTable::getTargetEqTags() const
 {
   return target_eqtags;
 }
 
-map<string, vector<int>>
+const map<string, vector<int>> &
 TrendComponentModelTable::getEqNums() const
 {
   return eqnums;
 }
 
-map<string, vector<int>>
+const map<string, vector<int>> &
 TrendComponentModelTable::getTargetEqNums() const
 {
   return target_eqnums;
 }
 
-vector<int>
+const vector<int> &
 TrendComponentModelTable::getTargetEqNums(const string &name_arg) const
 {
   checkModelName(name_arg);
   return target_eqnums.find(name_arg)->second;
 }
 
-map<string, vector<int>>
+const map<string, vector<int>> &
 TrendComponentModelTable::getNonTargetEqNums() const
 {
   return nontarget_eqnums;
 }
 
-vector<int>
+const vector<int> &
 TrendComponentModelTable::getNonTargetEqNums(const string &name_arg) const
 {
   checkModelName(name_arg);
   return nontarget_eqnums.find(name_arg)->second;
 }
 
-vector<int>
+const vector<int> &
 TrendComponentModelTable::getEqNums(const string &name_arg) const
 {
   checkModelName(name_arg);
   return eqnums.find(name_arg)->second;
 }
 
-vector<int>
+const vector<int> &
 TrendComponentModelTable::getMaxLags(const string &name_arg) const
 {
   checkModelName(name_arg);
@@ -231,14 +231,14 @@ TrendComponentModelTable::getMaxLag(const string &name_arg) const
   return max_lag_int;
 }
 
-vector<bool>
+const vector<bool> &
 TrendComponentModelTable::getDiff(const string &name_arg) const
 {
   checkModelName(name_arg);
   return diff.find(name_arg)->second;
 }
 
-vector<int>
+const vector<int> &
 TrendComponentModelTable::getOrigDiffVar(const string &name_arg) const
 {
   checkModelName(name_arg);
@@ -306,12 +306,12 @@ TrendComponentModelTable::writeOutput(const string &basename, ostream &output) c
       for (const auto &it : rhs.at(name))
         {
           output << "M_.trend_component." << name << ".rhs.vars_at_eq{" << i << "}.var = [";
-          for (const auto &it1 : it)
-            output << symbol_table.getTypeSpecificID(it1.first) + 1 << " ";
+          for (auto [var, lag] : it)
+            output << symbol_table.getTypeSpecificID(var) + 1 << " ";
           output << "];" << endl
                  << "M_.trend_component." << name << ".rhs.vars_at_eq{" << i << "}.lag = [";
-          for (const auto &it1 : it)
-            output << it1.second << " ";
+          for (auto [var, lag] : it)
+            output << lag << " ";
           output << "];" << endl;
 
           i++;
@@ -350,42 +350,40 @@ TrendComponentModelTable::writeOutput(const string &basename, ostream &output) c
       ar_ec_output << "if strcmp(model_name, '" << name << "')" << endl
                    << "    % AR" << endl
                    << "    AR = zeros(" << nontarget_lhs_vec.size() << ", " << nontarget_lhs_vec.size() << ", " << getMaxLag(name) << ");" << endl;
-      for (const auto &it : AR.at(name))
+      for (const auto &[key, expr] : AR.at(name))
         {
-          auto [eqn, lag, lhs_symb_id] = it.first;
+          auto [eqn, lag, lhs_symb_id] = key;
           int colidx = static_cast<int>(distance(nontarget_lhs_vec.begin(), find(nontarget_lhs_vec.begin(), nontarget_lhs_vec.end(), lhs_symb_id)));
           ar_ec_output << "    AR(" << eqn + 1 << ", " << colidx + 1 << ", " << lag << ") = ";
-          it.second->writeOutput(ar_ec_output, ExprNodeOutputType::matlabDynamicModel);
+          expr->writeOutput(ar_ec_output, ExprNodeOutputType::matlabDynamicModel);
           ar_ec_output << ";" << endl;
         }
 
       int a0_lag = 0;
-      for (const auto &it : A0.at(name))
-        if (get<1>(it.first) > a0_lag)
-          a0_lag = get<1>(it.first);
+      for (const auto &[key, expr] : A0.at(name))
+        a0_lag = max(a0_lag, get<1>(key));
       ar_ec_output << endl
                    << "    % A0" << endl
                    << "    A0 = zeros(" << nontarget_lhs_vec.size() << ", " << nontarget_lhs_vec.size() << ", " << a0_lag << ");" << endl;
-      for (const auto &it : A0.at(name))
+      for (const auto &[key, expr] : A0.at(name))
         {
-          auto [eqn, lag, colidx] = it.first;
+          auto [eqn, lag, colidx] = key;
           ar_ec_output << "    A0(" << eqn + 1 << ", " << colidx + 1 << ", " << lag << ") = ";
-          it.second->writeOutput(ar_ec_output, ExprNodeOutputType::matlabDynamicModel);
+          expr->writeOutput(ar_ec_output, ExprNodeOutputType::matlabDynamicModel);
           ar_ec_output << ";" << endl;
         }
 
       int a0star_lag = 0;
-      for (const auto &it : A0star.at(name))
-        if (get<1>(it.first) > a0star_lag)
-          a0star_lag = get<1>(it.first);
+      for (const auto &[key, expr] : A0star.at(name))
+        a0star_lag = max(a0star_lag, get<1>(key));
       ar_ec_output << endl
                    << "    % A0star" << endl
                    << "    A0star = zeros(" << nontarget_lhs_vec.size() << ", " << target_lhs_vec.size() << ", " << a0star_lag << ");" << endl;
-      for (const auto &it : A0star.at(name))
+      for (const auto &[key, expr] : A0star.at(name))
         {
-          auto [eqn, lag, colidx] = it.first;
+          auto [eqn, lag, colidx] = key;
           ar_ec_output << "    A0star(" << eqn + 1 << ", " << colidx + 1 << ", " << lag << ") = ";
-          it.second->writeOutput(ar_ec_output, ExprNodeOutputType::matlabDynamicModel);
+          expr->writeOutput(ar_ec_output, ExprNodeOutputType::matlabDynamicModel);
           ar_ec_output << ";" << endl;
         }
 
@@ -430,8 +428,7 @@ VarModelTable::VarModelTable(SymbolTable &symbol_table_arg) :
 }
 
 void
-VarModelTable::addVarModel(string name_arg, vector<string> eqtags_arg,
-                           pair<SymbolList, int> symbol_list_and_order_arg)
+VarModelTable::addVarModel(string name_arg, bool structural_arg, vector<string> eqtags_arg)
 {
   if (isExistingVarModelName(name_arg))
     {
@@ -439,24 +436,18 @@ VarModelTable::addVarModel(string name_arg, vector<string> eqtags_arg,
       exit(EXIT_FAILURE);
     }
 
+  structural[name_arg] = structural_arg;
   eqtags[name_arg] = move(eqtags_arg);
-  symbol_list_and_order[name_arg] = move(symbol_list_and_order_arg);
   names.insert(move(name_arg));
 }
 
-map<string, pair<SymbolList, int>>
-VarModelTable::getSymbolListAndOrder() const
-{
-  return symbol_list_and_order;
-}
-
 void
 VarModelTable::writeOutput(const string &basename, ostream &output) const
 {
   if (names.empty())
     return;
 
-  string filename = "+" + basename + "/var_ar.m";
+  string filename = "+" + basename + "/varmatrices.m";
   ofstream ar_output;
   ar_output.open(filename, ios::out | ios::binary);
   if (!ar_output.is_open())
@@ -464,20 +455,17 @@ VarModelTable::writeOutput(const string &basename, ostream &output) const
       cerr << "Error: Can't open file " << filename << " for writing" << endl;
       exit(EXIT_FAILURE);
     }
-  ar_output << "function ar = var_ar(model_name, params)" << endl
-            << "%function ar = var_ar(model_name, params)" << endl
-            << "% File automatically generated by the Dynare preprocessor" << endl << endl;
+  ar_output << "function [ar, a0, constants] = varmatrices(model_name, params, reducedform)" << endl
+            << "% File automatically generated by the Dynare preprocessor" << endl << endl
+            << "if nargin<3" << endl
+            << "    reducedform = false;" << endl
+            << "end" << endl << endl;
 
   for (const auto &name : names)
     {
-      output << "M_.var." << name << ".model_name = '" << name << "';" << endl;
-      if (!symbol_list_and_order.at(name).first.empty())
-        {
-          symbol_list_and_order.at(name).first.writeOutput("M_.var." + name + ".var_list_", output);
-          output << "M_.var." << name << ".order = "
-                 << symbol_list_and_order.at(name).second << ";" << endl;
-        }
-      output << "M_.var." << name << ".eqtags = {";
+      output << "M_.var." << name << ".model_name = '" << name << "';" << endl
+             << "M_.var." << name << ".structural = " << (structural.at(name) ? "true" : "false") << ";" << endl
+             << "M_.var." << name << ".eqtags = {";
       for (const auto &it : eqtags.at(name))
         output << "'" << it << "'; ";
       output << "};" << endl
@@ -506,12 +494,12 @@ VarModelTable::writeOutput(const string &basename, ostream &output) const
       for (const auto &it : rhs.at(name))
         {
           output << "M_.var." << name << ".rhs.vars_at_eq{" << i << "}.var = [";
-          for (const auto &it1 : it)
-            output << symbol_table.getTypeSpecificID(it1.first) + 1 << " ";
+          for (auto [var, lag] : it)
+            output << symbol_table.getTypeSpecificID(var) + 1 << " ";
           output << "];" << endl
                  << "M_.var." << name << ".rhs.vars_at_eq{" << i << "}.lag = [";
-          for (const auto &it1 : it)
-            output << it1.second << " ";
+          for (auto [var, lag] : it)
+            output << lag << " ";
           output << "];" << endl;
 
           i++;
@@ -520,19 +508,53 @@ VarModelTable::writeOutput(const string &basename, ostream &output) const
       vector<int> lhs = getLhsOrigIds(name);
       ar_output << "if strcmp(model_name, '" << name << "')" << endl
                 << "    ar = zeros(" << lhs.size() << ", " << lhs.size() << ", " << getMaxLag(name) << ");" << endl;
-      for (const auto &it : AR.at(name))
+      for (const auto &[key, expr] : AR.at(name))
         {
-          auto [eqn, lag, lhs_symb_id] = it.first;
+          auto [eqn, lag, lhs_symb_id] = key;
           int colidx = static_cast<int>(distance(lhs.begin(), find(lhs.begin(), lhs.end(), lhs_symb_id)));
-          ar_output << "    ar(" << eqn + 1 << ", " << colidx + 1 << ", " << lag << ") = ";
-          it.second->writeOutput(ar_output, ExprNodeOutputType::matlabDynamicModel);
+          ar_output << "    ar(" << eqn + 1 << "," << colidx + 1 << "," << lag << ") = ";
+          expr->writeOutput(ar_output, ExprNodeOutputType::matlabDynamicModel);
           ar_output << ";" << endl;
         }
-      ar_output << "    return" << endl
+      ar_output << "    if nargout>1" << endl
+                << "        a0 = eye(" << lhs.size() << ");" << endl;
+      for (const auto &[key, expr] : A0.at(name))
+        {
+          auto [eqn, lhs_symb_id] = key;
+          int colidx = static_cast<int>(distance(lhs.begin(), find(lhs.begin(), lhs.end(), lhs_symb_id)));
+          if (eqn!=colidx)
+            {
+              ar_output << "        a0(" << eqn + 1 << "," << colidx + 1 << ") = ";
+              expr->writeOutput(ar_output, ExprNodeOutputType::matlabDynamicModel);
+              ar_output << ";" << endl;
+            }
+        }
+      ar_output << "        if reducedform" << endl
+                << "            for i=1:" << getMaxLag(name) << endl
+                << "                ar(:,:,i) = a0\\ar(:,:,i);" << endl
+                << "            end" << endl
+                << "            if nargout<3" << endl
+                << "                a0 = eye(" << lhs.size() << ");" << endl
+                << "            end" << endl
+                << "        end" << endl
+                << "        if nargout>2" << endl
+                << "            constants = zeros(" << lhs.size() << ",1);" << endl;
+      for (auto [eqn, expr] : constants.at(name))
+        {
+          ar_output << "            constants(" << eqn + 1 << ") = ";
+          expr->writeOutput(ar_output, ExprNodeOutputType::matlabDynamicModel);
+          ar_output << ";" << endl;
+        }
+      ar_output << "        end" << endl
+                << "        if reducedform" << endl
+                << "            constants = a0\\constants;" << endl
+                << "            a0 = eye(" << lhs.size() << ");" << endl
+                << "        end" << endl
+                << "    end" << endl
+                << "    return" << endl
                 << "end" << endl << endl;
     }
-  ar_output << "error([model_name ' is not a valid var_model name'])" << endl
-            << "end" << endl;
+  ar_output << "error('%s is not a valid var_model name', model_name)" << endl;
   ar_output.close();
 }
 
@@ -544,31 +566,31 @@ VarModelTable::writeJsonOutput(ostream &output) const
       if (name != *names.begin())
         output << ", ";
       output << R"({"statementName": "var_model",)"
-             << R"("model_name": ")" << name << R"(",)";
-      if (symbol_list_and_order.empty())
+             << R"("model_name": ")" << name << R"(",)"
+             << R"("eqtags": [)";
+      for (const auto &it : eqtags.at(name))
         {
-          output << R"("eqtags": [)";
-          for (const auto &it : eqtags.at(name))
-            {
-              output << R"(")" << it << R"(")";
-              if (&it != &eqtags.at(name).back())
-                output << ", ";
-            }
-          output << "]";
+          output << R"(")" << it << R"(")";
+          if (&it != &eqtags.at(name).back())
+            output << ", ";
         }
-      else
-        output << R"("order": ")" << symbol_list_and_order.at(name).second << R"(")";
-      output << "}";
+      output << "]}";
     }
 }
 
-map<string, vector<string>>
+const map<string, bool> &
+VarModelTable::getStructural() const
+{
+  return structural;
+}
+
+const map<string, vector<string>> &
 VarModelTable::getEqTags() const
 {
   return eqtags;
 }
 
-vector<string>
+const vector<string> &
 VarModelTable::getEqTags(const string &name_arg) const
 {
   checkModelName(name_arg);
@@ -630,20 +652,20 @@ VarModelTable::setLhsExprT(map<string, vector<expr_t>> lhs_expr_t_arg)
   lhs_expr_t = move(lhs_expr_t_arg);
 }
 
-map<string, vector<int>>
+const map<string, vector<int>> &
 VarModelTable::getEqNums() const
 {
   return eqnums;
 }
 
-vector<bool>
+const vector<bool> &
 VarModelTable::getDiff(const string &name_arg) const
 {
   checkModelName(name_arg);
   return diff.find(name_arg)->second;
 }
 
-vector<int>
+const vector<int> &
 VarModelTable::getEqNums(const string &name_arg) const
 {
   checkModelName(name_arg);
@@ -674,7 +696,19 @@ VarModelTable::setAR(map<string, map<tuple<int, int, int>, expr_t>> AR_arg)
   AR = move(AR_arg);
 }
 
-vector<int>
+void
+VarModelTable::setA0(map<string, map<tuple<int, int>, expr_t>> A0_arg)
+{
+  A0 = move(A0_arg);
+}
+
+void
+VarModelTable::setConstants(map<string, map<int, expr_t>> constants_arg)
+{
+  constants = move(constants_arg);
+}
+
+const vector<int> &
 VarModelTable::getMaxLags(const string &name_arg) const
 {
   checkModelName(name_arg);
@@ -690,28 +724,28 @@ VarModelTable::getMaxLag(const string &name_arg) const
   return max_lag_int;
 }
 
-vector<int>
+const vector<int> &
 VarModelTable::getLhs(const string &name_arg) const
 {
   checkModelName(name_arg);
   return lhs.find(name_arg)->second;
 }
 
-vector<int>
+const vector<int> &
 VarModelTable::getLhsOrigIds(const string &name_arg) const
 {
   checkModelName(name_arg);
   return lhs_orig_symb_ids.find(name_arg)->second;
 }
 
-vector<set<pair<int, int>>>
+const vector<set<pair<int, int>>> &
 VarModelTable::getRhs(const string &name_arg) const
 {
   checkModelName(name_arg);
   return rhs.find(name_arg)->second;
 }
 
-vector<expr_t>
+const vector<expr_t> &
 VarModelTable::getLhsExprT(const string &name_arg) const
 {
   checkModelName(name_arg);
