@@ -1,5 +1,5 @@
 /*
- * Copyright © 2003-2020 Dynare Team
+ * Copyright © 2003-2021 Dynare Team
  *
  * This file is part of Dynare.
  *
@@ -14,7 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with Dynare.  If not, see <http://www.gnu.org/licenses/>.
+ * along with Dynare.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include <regex>
@@ -113,9 +113,6 @@ SymbolList::checkPass(WarningConsolidation &warnings,
               case SymbolType::unusedEndogenous:
                 valid_types += "unusedEndogenous, ";
                 break;
-              case SymbolType::endogenousVAR:
-                valid_types += "endogenousVAR, ";
-                break;
               case SymbolType::excludedVariable:
                 valid_types += "excludedVariable, ";
               }
