@@ -1,5 +1,5 @@
 function runDynareReport(dc_a, dc_q, db_a, db_q)
-% Copyright (C) 2013-2015 Dynare Team
+% Copyright (C) 2013-2019 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -14,7 +14,7 @@ function runDynareReport(dc_a, dc_q, db_a, db_q)
 % GNU General Public License for more details.
 %
 % You should have received a copy of the GNU General Public License
-% along with Dynare.  If not, see <http://www.gnu.org/licenses/>.
+% along with Dynare.  If not, see <https://www.gnu.org/licenses/>.
 
 tic
 larange= dates('2007a'):dates('2014a');
@@ -32,7 +32,7 @@ longNames  = {'Coca Cola', 'Kinder Bueno', 'Pizza', ...
               'Vegetarianism Is Good', 'OS X', 'Dothraki'};
 
 %% Begin Report
-rep = report();
+rep = report('title', 'Report Title', 'maketoc', true);
 
 
 %% Page 1: GDP
@@ -178,8 +178,8 @@ rep = rep.addSeries('data', db_q{'LRPOIL_BAR_WORLD'}, ...
 rep = rep.addGraph('title', 'World Real Food Price Index', ...
                    'xrange', prange, ...
                    'shade', srange, ...
-                   'xTicks', [1,5,10,15,find(srange(1)==prange),length(prange)], ...
-                   'xTickLabels',{startpoint{:},'2008Q1','2009Q2','2010Q3',shaded{:}, endpoint{:}},...
+                   'xTicks', 1:length(prange), ...
+                   'xTickLabels', strsplit(num2str(1:length(prange))), ...
                    'xTickLabelRotation', 0, ...
                    'showLegend', true, ...
                    'legendAt', [.5,.5]);
@@ -258,9 +258,9 @@ rep = rep.addSeries('graphHline', 460, ...
                     'graphLineWidth', 1.5);
 
 a=dseries([1:200]', '1984q1');
-b=a;
-c=a;
-d=a;
+b=copy(a);
+c=copy(a);
+d=copy(a);
 b(dates('2012q2'):dates('2015q2'))=b(dates('2012q2'):dates('2015q2'))+2;
 c(dates('2012q2'):dates('2015q2'))=c(dates('2012q2'):dates('2015q2'))+4;
 d(dates('2012q2'):dates('2015q2'))=d(dates('2012q2'):dates('2015q2'))+6;
