@@ -1,4 +1,4 @@
-## Copyright (C) 2009-2020 Dynare Team
+## Copyright (C) 2009-2022 Dynare Team
 ##
 ## This file is part of Dynare.
 ##
@@ -20,6 +20,9 @@
 ## Before every call to Dynare, the contents of the workspace is saved in
 ## 'wsOct', and reloaded after Dynare has finished (this is necessary since
 ## Dynare does a 'clear -all').
+## Note that we take care of clearing oo_ before saving the workspace,
+## otherwise the newly created oo_ will be scratched upon loading,
+## thus making the path comparison bogus.
 
 top_test_dir = getenv('TOP_TEST_DIR');
 addpath([top_test_dir filesep 'utils']);
@@ -30,11 +33,6 @@ if !strcmp(dynare_version(), getenv("DYNARE_VERSION"))
     error("Incorrect version of Dynare is being tested")
 endif
 
-## Ask gnuplot to create graphics in text mode
-## Note that setenv() was introduced in Octave 3.0.2, for compatibility
-## with MATLAB
-putenv("GNUTERM", "dumb")
-
 ## Test block_bytecode/ls2003.mod with various combinations of
 ## block/bytecode/solve_algo/stack_solve_algo
 failedBlock = {};
@@ -52,14 +50,16 @@ for blockFlag = 0:1
             solve_algos = [0:4 6:9];
             stack_solve_algos = 0:4;
         else
-            solve_algos = 0:8;
+            solve_algos = 0:9;
             stack_solve_algos = 0:5;
         endif
 
         # Workaround for strange race condition related to the static/dynamic
         # files (especially when we switch to/from use_dll)
-        rmdir('+ls2003_tmp', 's')
-        pause(1)
+        if exist('+ls2003_tmp')
+            rmdir('+ls2003_tmp', 's');
+            pause(1)
+        endif
 
         for i = 1:length(solve_algos)
             num_block_tests = num_block_tests + 1;
@@ -83,6 +83,7 @@ for blockFlag = 0:1
             else
                 try
                     old_path = path;
+                    clear oo_ # Ensure that oo_.endo_simul won’t be overwritten when loading wsOct
                     save wsOct
                     run_ls2003(blockFlag, storageFlag, solve_algos(i), default_stack_solve_algo)
                     load wsOct
@@ -90,7 +91,7 @@ for blockFlag = 0:1
                     ## Test against the reference simulation path
                     load('test.mat','y_ref');
                     diff = oo_.endo_simul - y_ref;
-                    if abs(diff) > options_.dynatol.x
+                    if max(max(abs(diff))) > options_.dynatol.x
                         failedBlock{size(failedBlock,2)+1} = ['block_bytecode' filesep 'run_ls2003.m(' num2str(blockFlag) ',' num2str(storageFlag) ',' num2str(solve_algos(i)) ',' num2str(default_stack_solve_algo) ')'];
                         differr.message = ["ERROR: simulation path differs from the reference path" ];
                         printMakeCheckOctaveErrMsg(['block_bytecode' filesep 'run_ls2003.m(' num2str(blockFlag) ',' num2str(storageFlag) ',' num2str(solve_algos(i)) ',' num2str(default_stack_solve_algo) ')'], differr);
@@ -107,6 +108,7 @@ for blockFlag = 0:1
             num_block_tests = num_block_tests + 1;
             try
                 old_path = path;
+                clear oo_ # Ensure that oo_.endo_simul won’t be overwritten when loading wsOct
                 save wsOct
                 run_ls2003(blockFlag, storageFlag, default_solve_algo, stack_solve_algos(i))
                 load wsOct
@@ -114,7 +116,7 @@ for blockFlag = 0:1
                 ## Test against the reference simulation path
                 load('test.mat','y_ref');
                 diff = oo_.endo_simul - y_ref;
-                if abs(diff) > options_.dynatol.x
+                if max(max(abs(diff))) > options_.dynatol.x
                     failedBlock{size(failedBlock,2)+1} = ['block_bytecode' filesep 'run_ls2003.m(' num2str(blockFlag) ',' num2str(storageFlag) ',' num2str(default_solve_algo) ',' num2str(stack_solve_algos(i)) ')'];
                     differr.message = ["ERROR: simulation path differs from the reference path" ];
                     printMakeCheckOctaveErrMsg(['block_bytecode' filesep 'run_ls2003.m(' num2str(blockFlag) ',' num2str(storageFlag) ',' num2str(default_solve_algo) ',' num2str(stack_solve_algos(i)) ')'], differr);
